<?php
if ( ! defined( 'ABSPATH' ) ) exit;

require_once plugin_dir_path(__FILE__) . '../includes/vegavend_api_config.php';

class Vegavend_Categories {
    private $api_endpoint;
    private $api_key;

    public function __construct() {
        $this->api_endpoint = Vegavend_API_Config::get_categories_url();
        $this->api_key = Vegavend_API_Config::get_api_key();
        add_action('product_cat_add_form_fields', [$this, 'add_vegavend_product_category_field'], 10, 2);
        add_action('product_cat_edit_form_fields', [$this, 'edit_vegavend_product_category_field'], 10, 2);
        add_action('edited_product_cat', [$this, 'save_vegavend_product_category_field'], 10, 2);
        add_action('create_product_cat', [$this, 'save_vegavend_product_category_field'], 10, 2);
        add_action('admin_enqueue_scripts', [$this, 'vegavend_enqueue_scripts']);
    }

    private function fetch_categories() {
        $response = wp_remote_post($this->api_endpoint, array(
            'headers' => array(
                'Content-Type' => 'application/json',
                'X-API-Key' => sanitize_text_field($this->api_key),
            ),
            'body' => '',
        ));

        if (is_wp_error($response)) {
            return [];
        }

        $response_body = wp_remote_retrieve_body($response);
        return json_decode($response_body, true);
    }

    private function generate_options($selected = '') {
        $categories = $this->fetch_categories();
        $options = '';
    
        if (is_array($categories) && !empty($categories)) {
            foreach ($categories as $category) {
                $selected_attr = ($selected == $category['id']) ? ' selected="selected"' : '';
                $options .= '<option value="' . esc_attr($category['id']) . '"' . $selected_attr . '>' . esc_html($category['name']) . '</option>';
            }
        }
    
        return $options;
    }

    public function vegavend_enqueue_scripts() {
        wp_enqueue_script('select2', VEGAVEND_PLUGIN_URL . '/assets/js/select2.min.js', array('jquery'), '4.1.0', true);
        wp_enqueue_style('select2-css', VEGAVEND_PLUGIN_URL . '/assets/css/select2.min.css', array(), '4.1.0');
        wp_add_inline_script('select2', 'jQuery(document).ready(function($) {
            $(".vegavend-product-category-select, .edit-vegavend-select").select2();
        });');
    }

    public function add_vegavend_product_category_field($taxonomy) {
        ?>
        <div class="form-field term-group">
            <label for="vegavend_product_category"><?php esc_html_e('VegaVend Product Category', 'vegavend-merchant-connector'); ?></label>
            <select id="vegavend_product_category" name="vegavend_product_category" class="vegavend-product-category-select">
                <?php
                   $allowed_html = array(
                    'option' => array(
                        'value' => array(),
                        'selected' => array()
                    )
                    );
                
                    // When calling the function, escape the output with custom allowed HTML
                    echo wp_kses($this->generate_options(), $allowed_html);
                 ?>
            </select>
            <?php wp_nonce_field('save_vegavend_product_category', 'vegavend_product_category_nonce'); ?>
        </div>
        <?php
    }

    public function edit_vegavend_product_category_field($term, $taxonomy) {
        $vegavend_product_category = get_term_meta($term->term_id, 'vegavend_product_category', true);
        ?>
        <tr class="form-field term-group-wrap">
            <th scope="row"><label for="vegavend_product_category"><?php esc_html_e('VegaVend Product Category', 'vegavend-merchant-connector'); ?></label></th>
            <td>
                <select id="vegavend_product_category" name="vegavend_product_category" class="vegavend-product-category-select edit-vegavend-select">
                    <?php
                        $allowed_html = array(
                         'option' => array(
                            'value' => array(),
                            'selected' => array()
                          )
                        );
                    
                        // When calling the function, escape the output with custom allowed HTML
                        echo wp_kses($this->generate_options(esc_attr($vegavend_product_category)), $allowed_html); 
                    ?>
                </select>
                <?php wp_nonce_field('save_vegavend_product_category', 'vegavend_product_category_nonce'); ?>
            </td>
        </tr>
        <?php
    }

    public function save_vegavend_product_category_field($term_id, $tt_id) {
        if (isset($_POST['vegavend_product_category_nonce']) && wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['vegavend_product_category_nonce'])), 'save_vegavend_product_category')) {
            if (isset($_POST['vegavend_product_category'])) {
                update_term_meta($term_id, 'vegavend_product_category', sanitize_text_field(wp_unslash($_POST['vegavend_product_category'])));
            }
        }
    }
}

new Vegavend_Categories();