<?php
if (!defined('ABSPATH')) {
    exit;
}
class Vegavend_Product_Fields {
    public function __construct() {
        add_action('woocommerce_product_options_general_product_data', array($this, 'add_gtin_and_mpn_to_simple_products'));
        add_action('woocommerce_product_after_variable_attributes', array($this, 'add_gtin_and_mpn_to_variations'), 10, 3);
        add_action('woocommerce_save_product_variation', array($this, 'save_gtin_and_mpn_variations'), 10, 2);
        add_action('woocommerce_process_product_meta', array($this, 'save_gtin_and_mpn_simple_products'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_scripts'));
    }

    public function enqueue_scripts() {
        // Remove the line that registers the non-existent JavaScript file
        // wp_register_script('vegavend-admin-script', plugins_url('/assets/js/admin-script.js', __FILE__), array('jquery'), '1.0.0', true);
        wp_localize_script('vegavend-admin-script', 'vegavendNonce', array(
            'nonce' => wp_create_nonce('vegavend_nonce_action')
        ));
    }

    public function add_gtin_and_mpn_to_simple_products() {
        global $product_object;
        if ($product_object->is_type('simple')) {
            woocommerce_wp_text_input(array(
                'id' => '_gtin',
                'label' => __('GTIN', 'vegavend-merchant-connector'),
                'desc_tip' => true,
                'description' => __('Enter the Global Trade Item Number (GTIN).', 'vegavend-merchant-connector'),
            ));

            woocommerce_wp_text_input(array(
                'id' => '_mpn',
                'label' => __('MPN', 'vegavend-merchant-connector'),
                'desc_tip' => true,
                'description' => __('Enter the Manufacturer Part Number (MPN).', 'vegavend-merchant-connector'),
            ));
        }
    }

    public function add_gtin_and_mpn_to_variations($loop, $variation_data, $variation) {
        woocommerce_wp_text_input(array(
            'id' => "variable_gtin{$loop}",
            'name' => "variable_gtin[{$loop}]",
            'label' => __('GTIN', 'vegavend-merchant-connector'),
            'value' => get_post_meta($variation->ID, '_gtin', true),
            'wrapper_class' => 'form-row form-row-first',
        ));

        woocommerce_wp_text_input(array(
            'id' => "variable_mpn{$loop}",
            'name' => "variable_mpn[{$loop}]",
            'label' => __('MPN', 'vegavend-merchant-connector'),
            'value' => get_post_meta($variation->ID, '_mpn', true),
            'wrapper_class' => 'form-row form-row-last',
        ));
    }

    public function save_gtin_and_mpn_variations($variation_id, $loop) {
        if (!isset($_POST['vegavend_nonce']) || !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['vegavend_nonce'])), 'vegavend_nonce_action')) {
            return;
        }

        $gtin = isset($_POST['variable_gtin'][$loop]) ? sanitize_text_field(wp_unslash($_POST['variable_gtin'][$loop])) : '';
        $mpn = isset($_POST['variable_mpn'][$loop]) ? sanitize_text_field(wp_unslash($_POST['variable_mpn'][$loop])) : '';

        update_post_meta($variation_id, '_gtin', $gtin);
        update_post_meta($variation_id, '_mpn', $mpn);
    }

    public function save_gtin_and_mpn_simple_products($product_id) {
        if (!isset($_POST['vegavend_nonce']) || !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['vegavend_nonce'])), 'vegavend_nonce_action')) {
            return;
        }

        $gtin = isset($_POST['_gtin']) ? sanitize_text_field(wp_unslash($_POST['_gtin'])) : '';
        $mpn = isset($_POST['_mpn']) ? sanitize_text_field(wp_unslash($_POST['_mpn'])) : '';

        update_post_meta($product_id, '_gtin', $gtin);
        update_post_meta($product_id, '_mpn', $mpn);
    }
}

new Vegavend_Product_Fields();
?>