jQuery.noConflict();
jQuery(document).ready(function($) {
    // Namespace variables to avoid conflicts
    var storeId = vegavendData.storeId; 
    var apiKey = vegavendData.apiKey;
    var nonce = vegavendData.nonce;

    if (!storeId) {
        console.error('Store ID is undefined');
        return;
    }

    // Fetch account data on page load
    fetchAccountData();

    function fetchAccountData(retryCount = 0) {
        var requestUrl = vegavendData.restUrl + 'vegavend-store-api/v1/accounts'; 

        $.ajax({
            url: requestUrl,
            method: 'POST',
            headers: {
                'X-Store-ID': storeId,
                'X-API-Key': apiKey,
                'X-WP-Nonce': nonce, // Add nonce header
                'Content-Type': 'application/json'
            },
            data: JSON.stringify({ action: 'fetch_account_data' }), 
            success: function(response) {
                if (response && response.data && response.data.account_data) {
                    populateFormFields(response.data.account_data);
                } else if (response && response.account_data) {
                    populateFormFields(response.account_data);
                } else {
                    console.error('Invalid response structure:', response);
                }
            },
            error: function(response) {
                console.error('Error fetching account data:', response);
                if (response.status === 429) {
                    console.warn('Rate limit exceeded, stopping retries');
                }
            }
        });
    }

    function populateFormFields(accountData) {
        $('#store_name').val(accountData.store_name || '');
        $('#store_email').val(accountData.store_email || '');
        $('#profile_picture').val(accountData.profile_picture || '');
        $('#store_banner').val(accountData.store_banner || '');
        $('#company_name').val(accountData.company_name || '');
        $('#store_address_street').val(accountData.store_address_street || '');
        $('#store_address_street_2').val(accountData.store_address_street_2 || '');
        $('#store_address_city').val(accountData.store_address_city || '');
        $('#store_address_postcode').val(accountData.store_address_postcode || '');
        $('#store_address_country').val(accountData.store_address_country || '');
        $('#company_id_number').val(accountData.company_id || '');
        $('#support_number').val(accountData.support_number || '');
        $('#vat_number').val(accountData.vat_number || '');
        tinymce.get('biography').setContent(accountData.biography || '');
        $('#phone_number').val(accountData.phone_number || '');
        tinymce.get('terms_and_conditions').setContent(accountData.terms_and_conditions || '');
        tinymce.get('refunds_policy').setContent(accountData.refunds_policy || '');
        tinymce.get('shipping_policy').setContent(accountData.shipping_policy || '');
        
        tinymce.get('warranty_policy').setContent(accountData.warranty_policy.policy || '');
        $('#warranty_policy_label').val(accountData.warranty_policy.label || '');
        $('#warranty_policy_type').val(accountData.warranty_policy.type || '');
        $('#warranty_policy_length').val(accountData.warranty_policy.length || '');
        $('#warranty_policy_length_value').val(accountData.warranty_policy.length_value || '');
        $('#warranty_policy_length_duration').val(accountData.warranty_policy.length_duration || '');
        $('input[name="warranty_policy_reasons[]"]').each(function() {
            var reason = $(this).val();
            $(this).prop('checked', accountData.warranty_policy.reasons.includes(reason));
        });

        var socialProfiles = accountData.social_profiles || {};
        $.each(socialProfiles, function(profile, value) {
            $('#' + profile).val(value || '');
        });

        var shippingMethodsContainer = $('#shipping_methods_container');
        shippingMethodsContainer.empty();
        var shippingMethods = accountData.shipping_methods || [];
        if (shippingMethods.length === 0) {
            addShippingMethodRow(0, {});
        } else {
            var index = 0;
            $.each(shippingMethods, function(_, method) {
                addShippingMethodRow(index++, method, true);
            });
        }

        if (!accountData.store_address_street && !accountData.store_address_city && !accountData.store_address_postcode && !accountData.store_address_country) {
            $('#store_address_street').val(vegavendData.woocommerceStoreAddress || '');
            $('#store_address_street_2').val(vegavendData.woocommerceStoreAddress2 || '');
            $('#store_address_city').val(vegavendData.woocommerceStoreCity || '');
            $('#store_address_postcode').val(vegavendData.woocommerceStorePostcode || '');
            $('#store_address_country').val(vegavendData.woocommerceStoreCountry || '');
        }

        if (accountData.profile_picture) {
            $('#profile_picture_preview').attr('src', accountData.profile_picture).css('display', 'block');
        }
        if (accountData.store_banner) {
            $('#store_banner_preview').attr('src', accountData.store_banner).css('display', 'block');
        }

        // Update verification statuses directly in the form
        if (accountData.verification_status) {
            $('#identification_verified').html(getVerificationStatusHtml(accountData.verification_status.identification));
            $('#address_verified').html(getVerificationStatusHtml(accountData.verification_status.address));
            $('#company_id_verified').html(getVerificationStatusHtml(accountData.verification_status.company_registration));
            $('#vat_number_verified').html(getVerificationStatusHtml(accountData.verification_status.vat_number));
        } else {
            console.error('Verification status data is missing:', accountData);
        }
    }

    function getVerificationStatusHtml(status) {
        var statusText = '';
        var statusColor = '';

        switch (status) {
            case 'Approved':
                statusText = 'Verified';
                statusColor = 'green';
                break;
            case 'Pending':
                statusText = 'Pending';
                statusColor = 'orange';
                break;
            case 'Cancelled':
                statusText = 'Cancelled';
                statusColor = 'red';
                break;
            default:
                statusText = 'Not Verified';
                statusColor = 'gray';
                break;
        }

        return `<span style="color: ${statusColor};">●</span> ${statusText}`;
    }

    function addShippingMethodRow(index, method, readOnly = false) {
        var selectedMethod = method.method_id || (method.cost ? 'flat_rate' : 'free_shipping');
        var region = getRegionFromZone(method.zone);
        var row = `
            <div class="shipping-method" data-index="${index}">
                <label style="margin-top: 10px; margin-bottom: 10px;">Region:</label>
                <select name="shipping_methods[${index}][region]" class="shipping-region-select" style="margin-top: 5px; margin-bottom: 10px;" ${readOnly ? 'disabled' : ''}>
                    <option value="Europe" ${region === 'Europe' ? 'selected' : ''}>Europe</option>
                    <option value="North America" ${region === 'North America' ? 'selected' : ''}>North America</option>
                    <option value="Asia" ${region === 'Asia' ? 'selected' : ''}>Asia</option>
                    <option value="Oceania" ${region === 'Oceania' ? 'selected' : ''}>Oceania</option>
                </select><br>

                <label style="margin-top: 10px; margin-bottom: 10px;">Zone:</label>
                <select name="shipping_methods[${index}][zone]" class="shipping-zone-select" style="margin-top: 5px; margin-bottom: 10px;" ${readOnly ? 'disabled' : ''}>
                    ${getZoneOptions(region, method.zone)}
                </select><br>

                <label style="margin-top: 10px; margin-bottom: 10px;">Method:</label>
                <select name="shipping_methods[${index}][method]" class="shipping-method-select" style="margin-top: 5px; margin-bottom: 10px;" ${readOnly ? 'disabled' : ''}>
                    <option value="flat_rate" ${selectedMethod === 'flat_rate' ? 'selected' : ''}>Flat Rate</option>
                    <option value="free_shipping" ${selectedMethod === 'free_shipping' ? 'selected' : ''}>Free Shipping</option>
                </select><br>

                <div class="shipping-method-details" style="display: flex; align-items: center;">
                    ${selectedMethod === 'flat_rate' ? `
                        <label style="margin-top: 10px; margin-bottom: 10px; margin-right: 5px;">Cost:</label>
                        <input type="text" name="shipping_methods[${index}][cost]" value="${method.cost || ''}" data-free-shipping-min-amount="${method.free_shipping_min_amount || ''}" style="width: 400px; margin-top: 10px; margin-bottom: 10px;" ${readOnly ? 'readonly' : ''}><br>
                    ` : `
                        <label style="margin-top: 10px; margin-bottom: 10px; margin-right: 5px;">Free from:</label>
                        <input type="text" name="shipping_methods[${index}][free_shipping_min_amount]" value="${method.free_shipping_min_amount || ''}" data-cost="${method.cost || ''}" style="width: 80px; margin-top: 10px; margin-bottom: 10px;" ${readOnly ? 'readonly' : ''}><br>
                    `}
                </div>

                <button type="button" class="remove-shipping-method" style="display: none;">Remove</button>
            </div>
        `;
        $('#shipping_methods_container').append(row);
        updateShippingMethodDetails(index, selectedMethod, method);
    }

    function updateShippingMethodDetails(index, method, existingMethod = {}) {
        try {
            var detailsContainer = $(`.shipping-method[data-index="${index}"] .shipping-method-details`);
            if (method === 'flat_rate') {
                var freeShippingMinAmount = detailsContainer.find('input[name="shipping_methods[' + index + '][free_shipping_min_amount]"]').data('free-shipping-min-amount');
                detailsContainer.html(`
                    <label style="margin-top: 10px; margin-bottom: 10px; margin-right: 5px;">Cost:</label>
                    <input type="text" name="shipping_methods[${index}][cost]" value="${existingMethod.cost || ''}" data-free-shipping-min-amount="${freeShippingMinAmount || ''}" style="width: 80px; margin-top: 10px; margin-bottom: 10px;" readonly><br>
                `);
            } else if (method === 'free_shipping') {
                var cost = detailsContainer.find('input[name="shipping_methods[' + index + '][cost]"]').data('cost');
                detailsContainer.html(`
                    <label style="margin-top: 10px; margin-bottom: 10px; margin-right: 5px;">Free from:</label>
                    <input type="text" name="shipping_methods[${index}][free_shipping_min_amount]" value="${existingMethod.free_shipping_min_amount || ''}" data-cost="${cost || ''}" style="width: 80px; margin-top: 10px; margin-bottom: 10px;" readonly><br>
                `);
            } else {
                console.error('Unknown shipping method:', method);
            }
        } catch (error) {
            console.error('Error updating shipping method details:', error);
        }
    }

    function getRegionFromZone(zone) {
        var regions = {
            'Europe': ['EU', 'GB', 'DE', 'NL', 'FR', 'ES', 'IT', 'BE', 'IE'],
            'North America': ['US', 'CA', 'MX'],
            'Asia': ['CN', 'JP', 'IN'],
            'Oceania': ['AU', 'NZ']
        };

        for (var region in regions) {
            if (regions[region].includes(zone)) {
                return region;
            }
        }
        return 'Europe'; // Default to Europe if not found
    }

    function getZoneOptions(region, selectedZone) {
        var zones = {
            'Europe': ['EU', 'GB', 'DE', 'NL', 'FR', 'ES', 'IT', 'BE', 'IE'],
            'North America': ['US', 'CA', 'MX'],
            'Asia': ['CN', 'JP', 'IN'],
            'Oceania': ['AU', 'NZ']
        };

        if (!zones[region]) {
            return `<option value="${region}" ${selectedZone === region ? 'selected' : ''}>${region}</option>`;
        }

        return zones[region].map(zone => `<option value="${zone}" ${selectedZone === zone ? 'selected' : ''}>${zone}</option>`).join('');
    }

    $('#add_shipping_method').on('click', function() {
        var index = $('#shipping_methods_container .shipping-method').length;
        addShippingMethodRow(index, {});
    });

    $(document).on('change', '.shipping-method-select', function() {
        var method = $(this).val();
        var index = $(this).closest('.shipping-method').data('index');
        var existingMethod = {
            cost: $(`input[name="shipping_methods[${index}][cost]"]`).val(),
            free_shipping_min_amount: $(`input[name="shipping_methods[${index}][free_shipping_min_amount]"]`).val()
        };
        updateShippingMethodDetails(index, method, existingMethod);
    });

    $(document).on('change', '.shipping-region-select', function() {
        var region = $(this).val();
        var index = $(this).closest('.shipping-method').data('index');
        var zoneSelect = $(`select[name="shipping_methods[${index}][zone]"]`);
        zoneSelect.html(getZoneOptions(region, zoneSelect.val()));
    });

    $(document).on('click', '.remove-shipping-method', function() {
        $(this).closest('.shipping-method').remove();
    });

    $('#vegavend-account-form').on('submit', function(e) {
        e.preventDefault();

        var formData = new FormData(this);

        formData.append('profile_picture', $('#profile_picture').val());
        formData.append('store_banner', $('#store_banner').val());
        formData.append('_wpnonce', nonce); // Add nonce to form data

        $('body').append('<div id="loader">Updating Account<div id="loader-circle"></div></div>');
        $('body').append('<div id="overlay"></div>');

        $.ajax({
            url: vegavendData.ajaxurl,
            type: 'POST',
            data: formData,
            processData: false,
            contentType: false,
            success: function(response) {
                if (response.success) {
                    $('body').append('<div id="updated-banner">Account Updated</div>');
                    setTimeout(function() {
                        $('#updated-banner').fadeOut(function() {
                            $(this).remove();
                        });
                    }, 1000);
                } else {
                    alert('Failed to update account data.');
                }
            },
            error: function(xhr, status, error) {
                console.error('AJAX Error:', status, error);
                alert('An error occurred while updating account data.');
            },
            complete: function() {
                $('#loader').remove();
                $('#overlay').remove();
            }
        });
    });

    $('#edit_profile_picture').on('click', function() {
        var frame = wp.media({
            title: 'Select or Upload Profile Picture',
            button: {
                text: 'Use this picture'
            },
            multiple: false
        });

        frame.on('select', function() {
            var attachment = frame.state().get('selection').first().toJSON();
            $('#profile_picture').val(attachment.url);
            $('#profile_picture_preview').attr('src', attachment.url).css('display', 'block');
        });

        frame.open();
    });

    $('#edit_store_banner').on('click', function() {
        var frame = wp.media({
            title: 'Select or Upload Store Banner',
            button: {
                text: 'Use this banner'
            },
            multiple: false
        });

        frame.on('select', function() {
            var attachment = frame.state().get('selection').first().toJSON();
            $('#store_banner').val(attachment.url);
            $('#store_banner_preview').attr('src', attachment.url).css('display', 'block');
        });

        frame.open();
    });

    $('#store_seo_title').on('input', function() {
        var count = $(this).val().length;
        $('#seo_title_counter').text(count + '/57');
    });

    $('#store_seo_meta_description').on('input', function() {
        var count = $(this).val().length;
        $('#seo_meta_description_counter').text(count + '/156');
    });

    $('#store_seo_keywords').on('input', function() {
        var count = $(this).val().length;
        $('#seo_keywords_counter').text(count + '/55');
    });

    $('#store_seo_title').trigger('input');
    $('#store_seo_meta_description').trigger('input');
    $('#store_seo_keywords').trigger('input');

    $('#add_terms_template').on('click', function() {
        fetch(vegavendData.pluginUrl + '/includes/templates/terms-condition.php')
            .then(response => response.text())
            .then(data => {
                tinymce.get('terms_and_conditions').setContent(data);
            })
            .catch(error => console.error('Error loading terms-condition.php:', error));
    });

    $(document).on('mouseenter', '.dashicons-editor-help', function() {
        var title = $(this).attr('title');
        $(this).data('title', title).removeAttr('title');
        $('<div class="tooltip"></div>').text(title).appendTo('body').fadeIn('slow').show();
    }).on('mouseleave', '.dashicons-editor-help', function() {
        $(this).attr('title', $(this).data('title'));
        $('.tooltip').remove();
    }).on('mousemove', '.dashicons-editor-help', function(e) {
        var mouseX = e.pageX + 15;
        var mouseY = e.pageY + 15;
        $('.tooltip').css({ top: mouseY, left: mouseX });
    });

    $(document).on('click', function() {
        $('.tooltip').remove();
    });

    function toggleWarrantyFields() {
        var warrantyType = $('#warranty_policy_type').val();
        var warrantyLength = $('#warranty_policy_length').val();
        
        if (warrantyType === 'no_warranty') {
            $('#warranty_policy_length').closest('div').hide();
            $('#warranty_policy_length_value').closest('div').hide();
            $('#warranty_policy_length_duration').closest('div').hide();
        } else {
            $('#warranty_policy_length').closest('div').show();
            if (warrantyLength === 'lifetime') {
                $('#warranty_policy_length_value').closest('div').hide();
                $('#warranty_policy_length_duration').closest('div').hide();
            } else {
                $('#warranty_policy_length_value').closest('div').show();
                $('#warranty_policy_length_duration').closest('div').show();
            }
        }
    }

    $('#warranty_policy_type').on('change', toggleWarrantyFields);
    $('#warranty_policy_length').on('change', toggleWarrantyFields);
    toggleWarrantyFields();

    tinymce.init({
        selector: '#biography, #terms_and_conditions, #refunds_policy, #shipping_policy, #warranty_policy',
        toolbar: 'bold italic',
        setup: function(editor) {
            editor.on('init', function() {
            });
        }
    });
});

jQuery('<style>')
    .prop('type', 'text/css')
    .html(`
        .tooltip {
            position: absolute;
            background: #333;
            color: #fff;
            padding: 5px 10px;
            border-radius: 5px;
            z-index: 1000;
            display: none;
        }
    `)
    .appendTo('head');

jQuery('<style>')
    .prop('type', 'text/css')
    .html(`
        @keyframes spin {
            0% { transform: rotate(0deg); }
            100% { transform: rotate(360deg); }
        }
    `)
    .appendTo('head');