jQuery(document).ready(function(jQuery) {

    jQuery('#vegavend-edit-store-id').on('click', function() {
        if (confirm(vegavendSettings.confirmDisconnect)) {
            jQuery('#vegavend_store_id').val('');
            jQuery('#vegavend_store_id').removeAttr('readonly');
            jQuery('#vegavend-edit-store-id').hide();
            jQuery('#vegavend-save-store-id').show();

            // Remove store ID from the database
            var data = {
                action: 'vegavend_delete_store_id',
                vegavend_nonce: vegavendSettings.nonce
            };

            jQuery.post(vegavendSettings.ajaxurl, data, function(response) {
                if (response.success) {
                    location.reload(); // Reload the page to reflect the disconnected state
                } else {
                    console.log(vegavendSettings.storeIdDeleteFailed);
                }
            }).fail(function(xhr, status, error) {
                if (xhr.status === 403) {
                    console.log('You do not have permission to perform this action.');
                }
                console.log(vegavendSettings.ajaxFailed + ' ' + status + ', ' + error);
            });
        }
    });

    jQuery('#vegavend-settings-form').on('submit', function(event) {
        event.preventDefault();
        if (jQuery('#vegavend-save-store-id').is(':visible')) {
            var storeId = jQuery('#vegavend_store_id').val();
            var data = {
                action: 'vegavend_check_store_id',
                store_id: storeId,
                vegavend_nonce: vegavendSettings.nonce
            };

            jQuery.post(vegavendSettings.ajaxurl, data, function(response) {
                if (response.success) {
                    jQuery('#store-connected').show();
                    jQuery('#store-not-connected').hide();
                    // Save the store ID in the database
                    jQuery('#vegavend-settings-form').unbind('submit').submit();
                } else {
                    jQuery('#store-connected').hide();
                    jQuery('#store-not-connected').show();
                }
            }).fail(function(xhr, status, error) {
                if (xhr.status === 403) {
                    console.log('You do not have permission to perform this action.');
                }
                console.log(vegavendSettings.ajaxFailed + ' ' + status + ', ' + error);
            });
        } else if (jQuery('.vegavend-save-settings').is(':visible')) {
            // Save general settings without disconnecting the store
            jQuery('#vegavend-settings-form').unbind('submit').submit();
        }
    });

    jQuery('#vegavend-general-settings-form').on('submit', function(event) {
        event.preventDefault();
        // Save general settings without disconnecting the store
        var syncViaCron = jQuery('#vegavend_sync_via_cron').is(':checked') ? 1 : 0;
        jQuery('#vegavend_sync_via_cron_hidden').remove(); // Remove any existing hidden input
        jQuery('<input>').attr({
            type: 'hidden',
            id: 'vegavend_sync_via_cron_hidden',
            name: 'vegavend_sync_via_cron',
            value: syncViaCron
        }).appendTo('#vegavend-general-settings-form');
        jQuery('#vegavend-general-settings-form').unbind('submit').submit();
    });

    // Fetch store ID from the database
    var fetchData = { action: 'vegavend_get_store_id', vegavend_nonce: vegavendSettings.nonce };

    jQuery.post(vegavendSettings.ajaxurl, fetchData, function(response) {
        if (response.success) {
            jQuery('#vegavend_store_id').val(response.data.store_id);
        } else {
            console.log(vegavendSettings.storeIdFetchFailed);
        }
    }).fail(function(xhr, status, error) {
        if (xhr.status === 403) {
            console.log('You do not have permission to perform this action.');
        }
        console.log(vegavendSettings.ajaxFailed + ' ' + status + ', ' + error);
    });

    jQuery('#vegavend-sync-all').on('click', function() {
        if (vegavendSettings.allTasksCompleted && jQuery('#vegavend-sync-all').is(':visible') && confirm(vegavendSettings.confirmSyncAll)) {
            var data = {
                action: 'vegavend_sync_all_products',
                vegavend_nonce: vegavendSettings.nonce
            };

            jQuery.post(vegavendSettings.ajaxurl, data, function(response) {
                if (response.success) {
                    alert(vegavendSettings.syncAllSuccess);
                    // Add query parameter to indicate tasks completion
                    var url = new URL(window.location.href);
                    url.searchParams.set('tasks_completed', '1');
                    window.history.replaceState({}, '', url);
                } else {
                    console.log(vegavendSettings.syncAllFailed);
                }
            }).fail(function(xhr, status, error) {
                if (xhr.status === 403) {
                    console.log('You do not have permission to perform this action.');
                }
                console.log(vegavendSettings.ajaxFailed + ' ' + status + ', ' + error);
            });
        } else {
            alert('All tasks must be completed before syncing.');
        }
    });

    // Show or hide the "Sync All" button based on the task completion status and checkbox state on page load
    if (vegavendSettings.allTasksCompleted && jQuery('#vegavend_sync_via_cron').is(':checked')) {
        jQuery('#vegavend-sync-all').show();
    } else {
        jQuery('#vegavend-sync-all').hide();
    }

    // Show or hide the "Sync All" button based on the checkbox state
    jQuery('#vegavend_sync_via_cron').on('change', function() {
        if (vegavendSettings.allTasksCompleted && jQuery(this).is(':checked')) {
            jQuery('#vegavend-sync-all').show();
        } else {
            jQuery('#vegavend-sync-all').hide();
        }
    });

    // Show success popup if all tasks are completed
    if (vegavendSettings.allTasksCompleted && new URLSearchParams(window.location.search).has('tasks_completed')) {
        var successPopup = jQuery('<div id="vegavend-success-popup" class="notice notice-success is-dismissible"><p>' + vegavendSettings.successMessage + '</p></div>');
        jQuery('body').append(successPopup);
        setTimeout(function() {
            successPopup.fadeOut('slow', function() {
                jQuery(this).remove();
            });
        }, 3000);
    }
});
