<?php
// Include the API config file
require_once plugin_dir_path(__FILE__) . '../vegavend_api_config.php';

// Define the variables to avoid undefined variable errors
$store_name = get_option('vegavend_store_name');
$store_email = get_option('vegavend_store_email');
$store_id = get_option('vegavend_store_id');
$masked_store_id = str_repeat('*', strlen($store_id) - 4) . substr($store_id, -4);
$profile_picture = get_option('vegavend_profile_picture');
$store_banner = get_option('vegavend_store_banner');
$company_name = get_option('vegavend_company_name');
$store_address_street = get_option('vegavend_store_address_street');
$store_address_street_2 = get_option('vegavend_store_address_street_2');
$store_address_city = get_option('vegavend_store_address_city');
$store_address_postcode = get_option('vegavend_store_address_postcode');
$store_address_country = get_option('vegavend_store_address_country');
$company_id = get_option('vegavend_company_id');
$vat_number = get_option('vegavend_vat_number');
$biography = get_option('vegavend_biography');
$phone_number = get_option('vegavend_phone_number');
$social_profiles = maybe_unserialize(get_option('vegavend_social_profiles'));
if (!is_array($social_profiles)) {
    $social_profiles = array();
}
$shipping_methods = maybe_unserialize(get_option('vegavend_shipping_methods'));
$warranty_policy = maybe_unserialize(get_option('vegavend_warranty_policy'));
if (!is_array($warranty_policy)) {
    $warranty_policy = array(
        'addon_settings' => array(),
        'policy' => __('Add your warranty policy here.', 'vegavend-merchant-connector'),
        'label' => __('Warranty', 'vegavend-merchant-connector'),
        'type' => 'included_warranty',
        'length' => 'limited',
        'length_value' => '30',
        'length_duration' => 'days',
        'reasons' => array()
    );
}

$stripe_connected = get_option('vegavend_stripe_connected');
$payment_method = get_option('vegavend_payment_method');
$store_seo_title = get_option('vegavend_store_seo_title');
$store_seo_meta_description = get_option('vegavend_store_seo_meta_description');
$store_seo_keywords = get_option('vegavend_store_seo_keywords');

// Add verification status variables
$verification_statuses = array(
    'identification' => get_option('vegavend_identification_verified'),
    'address' => get_option('vegavend_address_verified'),
    'company_registration' => get_option('vegavend_company_id_verified'),
    'vat_number' => get_option('vegavend_vat_number_verified')
);

$countries = new WC_Countries();
$country_options = $countries->get_countries();

$profile_picture_placeholder = plugins_url('assets/images/profile-placeholder.jpg', dirname(__FILE__));
$store_banner_placeholder = plugins_url('assets/images/banner-placeholder.jpg', dirname(__FILE__));

// Add this function to modify TinyMCE settings
function disable_link_button_in_editor($settings) {
    $settings['toolbar1'] = str_replace('link', '', $settings['toolbar1']);
    return $settings;
}
add_filter('tiny_mce_before_init', 'disable_link_button_in_editor');

wp_enqueue_style('vegavend-account-css', plugins_url('assets/css/vegavend-account.css', dirname(__FILE__)), array(), time());

?>

<form id="vegavend-account-form" enctype="multipart/form-data" action="<?php echo esc_url(admin_url('admin-ajax.php')); ?>" method="POST">
    <?php wp_nonce_field('vegavend_nonce', 'vegavend_nonce'); ?>
    <input type="hidden" name="action" value="vegavend_update_account">
    <h1><?php esc_html_e('VegaVend Account', 'vegavend-merchant-connector'); ?></h1>
    
    <div style="margin-top: 30px;"></div>

    <div>
        <label for="store_name"><?php esc_html_e('Store Name', 'vegavend-merchant-connector'); ?></label>
        <input type="text" id="store_name" name="store_name" value="<?php echo esc_attr($store_name); ?>" readonly>
    </div>
    <div>
        <label for="store_email"><?php esc_html_e('Store Email', 'vegavend-merchant-connector'); ?></label>
        <input type="email" id="store_email" name="store_email" value="<?php echo esc_attr($store_email); ?>" readonly>
    </div>
    <div>
        <label for="store_id"><?php esc_html_e('Store ID', 'vegavend-merchant-connector'); ?></label>
        <input type="text" id="store_id" name="store_id" value="<?php echo esc_attr($masked_store_id); ?>" readonly>
    </div>
    <input type="hidden" id="unmasked_store_id" name="unmasked_store_id" value="<?php echo esc_attr($store_id); ?>">

    <div style="margin-top: 30px;"></div>

    <h2><?php esc_html_e('Profile Images', 'vegavend-merchant-connector'); ?></h2>
    <div class="profile-images" style="display: flex; align-items: center; margin: 10px 0;">
        <div style="margin-right: 20px;">
            <label for="profile_picture_upload"><?php esc_html_e('Profile Picture', 'vegavend-merchant-connector'); ?> <span class="dashicons dashicons-editor-help" title="<?php esc_attr_e('Add you company logo JPEG 500x500 pixels', 'vegavend-merchant-connector'); ?>"></span></label><br>
            <?php if ($profile_picture): ?>
                <img id="profile_picture_preview" src="<?php echo esc_url($profile_picture); ?>" alt="<?php esc_attr_e('Profile Picture', 'vegavend-merchant-connector'); ?>" width="70" height="70" style="margin: 5px 0; display: block;"><br>
            <?php else: ?>
                <img id="profile_picture_preview" src="<?php echo esc_url($profile_picture_placeholder); ?>" alt="<?php esc_attr_e('Profile Picture Placeholder', 'vegavend-merchant-connector'); ?>" width="70" height="70" style="margin: 5px 0; display: block;"><br>
            <?php endif; ?>
            <button type="button" id="edit_profile_picture"><?php esc_html_e('Edit', 'vegavend-merchant-connector'); ?></button>
            <input type="hidden" id="profile_picture" name="profile_picture" value="<?php echo esc_attr($profile_picture); ?>">
            <input type="file" id="profile_picture_upload" name="profile_picture_upload" accept="image/jpeg" style="display: none;">
        </div>
        <div>
            <label for="store_banner_upload"><?php esc_html_e('Store Banner', 'vegavend-merchant-connector'); ?> <span class="dashicons dashicons-editor-help" title="<?php esc_attr_e('Add a banner for your store, JPEG 1900x400 pixels', 'vegavend-merchant-connector'); ?>"></span></label><br>
            <?php if ($store_banner): ?>
                <img id="store_banner_preview" src="<?php echo esc_url($store_banner); ?>" alt="<?php esc_attr_e('Store Banner', 'vegavend-merchant-connector'); ?>" style="height: 70px; width: auto; margin: 5px 0; display: block;"><br>
            <?php else: ?>
                <img id="store_banner_preview" src="<?php echo esc_url($store_banner_placeholder); ?>" alt="<?php esc_attr_e('Store Banner Placeholder', 'vegavend-merchant-connector'); ?>" style="height: 70px; width: auto; margin: 5px 0; display: block;"><br>
            <?php endif; ?>
            <button type="button" id="edit_store_banner"><?php esc_html_e('Edit', 'vegavend-merchant-connector'); ?></button>
            <input type="hidden" id="store_banner" name="store_banner" value="<?php echo esc_attr($store_banner); ?>">
            <input type="file" id="store_banner_upload" name="store_banner_upload" accept="image/jpeg" style="display: none;">
        </div>
    </div>

    <div style="margin-top: 30px;"></div>

    <h2><?php esc_html_e('Store Information', 'vegavend-merchant-connector'); ?></h2>
    <label for="company_name"><?php esc_html_e('Company Name', 'vegavend-merchant-connector'); ?> <span class="dashicons dashicons-editor-help" title="<?php esc_attr_e('Your registered company name as it appears on the registration documents.', 'vegavend-merchant-connector'); ?>"></span></label>
    <input type="text" id="company_name" name="company_name" value="<?php echo esc_attr($company_name); ?>"><br>
    
    <div style="margin-top: 10px;"></div>

    <label for="support_number"><?php esc_html_e('Support Number', 'vegavend-merchant-connector'); ?> <span class="dashicons dashicons-editor-help" title="<?php esc_attr_e('A number where we can reach you in case it\'s urgent.', 'vegavend-merchant-connector'); ?>"></span></label>
    <input type="text" id="support_number" name="support_number" value="<?php echo esc_attr(get_option('vegavend_support_number')); ?>">

    <div style="margin-top: 10px;"></div>

    <h3><?php esc_html_e('Address', 'vegavend-merchant-connector'); ?> <span class="dashicons dashicons-editor-help" title="<?php esc_attr_e('Your registered address and place of business.', 'vegavend-merchant-connector'); ?>"></span></h3>
    <div class="address-block">
        <label for="store_address_street"><?php esc_html_e('Street', 'vegavend-merchant-connector'); ?></label>
        <input type="text" id="store_address_street" name="store_address_street" value="<?php echo esc_attr($store_address_street); ?>" style="margin-bottom: 10px;"><br>
        <label for="store_address_street_2"><?php esc_html_e('Street 2', 'vegavend-merchant-connector'); ?></label>
        <input type="text" id="store_address_street_2" name="store_address_street_2" value="<?php echo esc_attr($store_address_street_2); ?>" style="margin-bottom: 10px;"><br>
        <label for="store_address_city"><?php esc_html_e('City', 'vegavend-merchant-connector'); ?></label>
        <input type="text" id="store_address_city" name="store_address_city" value="<?php echo esc_attr($store_address_city); ?>" style="margin-bottom: 10px;"><br>
        <label for="store_address_postcode"><?php esc_html_e('Post/Zip Code', 'vegavend-merchant-connector'); ?></label>
        <input type="text" id="store_address_postcode" name="store_address_postcode" value="<?php echo esc_attr($store_address_postcode); ?>" style="margin-bottom: 10px;"><br>
        <label for="store_address_country"><?php esc_html_e('Country', 'vegavend-merchant-connector'); ?></label>
        <select id="store_address_country" name="store_address_country" style="margin-bottom: 10px;">
            <?php foreach ($country_options as $code => $name): ?>
                <option value="<?php echo esc_attr($code); ?>" <?php selected($store_address_country, $code); ?>><?php echo esc_html($name); ?></option>
            <?php endforeach; ?>
        </select><br>
    </div>

    <div style="margin-top: 10px;"></div>

    <h3><?php esc_html_e('Company Info', 'vegavend-merchant-connector'); ?></h3>
    <label for="company_id_number"><?php esc_html_e('Company ID Number', 'vegavend-merchant-connector'); ?> <span class="dashicons dashicons-editor-help" title="<?php esc_attr_e('Your company\'s registration number or if you are a sole trader your UTR number.', 'vegavend-merchant-connector'); ?>"></span></label>
    <input type="text" id="company_id_number" name="company_id_number" value="<?php echo esc_attr($company_id); ?>"><br>

    <div style="margin-top: 10px;"></div>

    <label for="vat_number"><?php esc_html_e('VAT Number', 'vegavend-merchant-connector'); ?> <span class="dashicons dashicons-editor-help" title="<?php esc_attr_e('Optional if you are based in the UK with a turnover of less than £75,000; otherwise, this is a requirement under UK law.', 'vegavend-merchant-connector'); ?>"></span></label>
    <input type="text" id="vat_number" name="vat_number" value="<?php echo esc_attr($vat_number); ?>"><br>

    <div style="margin-top: 20px;"></div>

    <h2><?php esc_html_e('Biography', 'vegavend-merchant-connector'); ?></h2>
    <div style="max-width: 600px;">
        <?php
        wp_editor(
            wp_kses_post($biography),
            'biography',
            array(
                'textarea_name' => 'biography',
                'textarea_rows' => 5,
                'media_buttons' => false,
                'teeny' => true,
            )
        );
        ?>
    </div>
    <div style="margin-top: 40px;"></div>

    <h2><?php esc_html_e('Store Policies', 'vegavend-merchant-connector'); ?></h2>

    <h3><?php esc_html_e('Terms and Conditions', 'vegavend-merchant-connector'); ?></h3>
    <div style="max-width: 600px;">
        <button type="button" id="add_terms_template" class="add-template-button" style="display: none;"><?php esc_html_e('Add Template', 'vegavend-merchant-connector'); ?></button>
        <?php
        wp_editor(
            wp_kses_post(get_option('vegavend_terms_and_conditions')),
            'terms_and_conditions',
            array(
                'textarea_name' => 'terms_and_conditions',
                'textarea_rows' => 5,
                'media_buttons' => false,
                'teeny' => true,
            )
        );
        ?>
    </div>

    <div style="margin-top: 40px;"></div>

    <h3><?php esc_html_e('Refunds Policy', 'vegavend-merchant-connector'); ?></h3>
    <div style="max-width: 600px;">
        <button type="button" id="add_refunds_template" class="add-template-button" style="display: none;"><?php esc_html_e('Add Template', 'vegavend-merchant-connector'); ?></button>
        <?php
        wp_editor(
            wp_kses_post(get_option('vegavend_refunds_policy')),
            'refunds_policy',
            array(
                'textarea_name' => 'refunds_policy',
                'textarea_rows' => 5,
                'media_buttons' => false,
                'teeny' => true,
            )
        );
        ?>
    </div>

    <div style="margin-top: 40px;"></div>

    <h3><?php esc_html_e('Shipping Policy', 'vegavend-merchant-connector'); ?></h3>
    <div style="max-width: 600px;">
        <button type="button" id="add_shipping_template" class="add-template-button" style="display: none;"><?php esc_html_e('Add Template', 'vegavend-merchant-connector'); ?></button>
        <?php
        wp_editor(
            wp_kses_post(get_option('vegavend_shipping_policy')),
            'shipping_policy',
            array(
                'textarea_name' => 'shipping_policy',
                'textarea_rows' => 5,
                'media_buttons' => false,
                'teeny' => true,
            )
        );
        ?>
    </div>

    <div style="margin-top: 40px;"></div>

    <h3><?php esc_html_e('Warranty Policy', 'vegavend-merchant-connector'); ?></h3>
    <div style="max-width: 600px;">
        <button type="button" id="add_warranty_template" class="add-template-button" style="display: none;"><?php esc_html_e('Add Template', 'vegavend-merchant-connector'); ?></button>
        <?php
        wp_editor(
            wp_kses_post($warranty_policy['policy']), 
            'warranty_policy',
            array(
                'textarea_name' => 'warranty_policy',
                'textarea_rows' => 5,
                'media_buttons' => false,
                'teeny' => true,
            )
        );
        ?>
    </div>

    <h3><?php esc_html_e('Warranty Settings', 'vegavend-merchant-connector'); ?></h3>
    <label for="warranty_policy_label" style="margin-top: 10px; margin-bottom: 10px;"><?php esc_html_e('Warranty Label', 'vegavend-merchant-connector'); ?></label>
    <input type="text" id="warranty_policy_label" name="warranty_policy_label" value="<?php echo esc_attr($warranty_policy['label']); ?>"><br>
    <label for="warranty_policy_type" style="margin-top: 10px; margin-bottom: 10px;"><?php esc_html_e('Warranty Type', 'vegavend-merchant-connector'); ?></label>
    <select id="warranty_policy_type" name="warranty_policy_type">
        <option value="no_warranty" <?php selected($warranty_policy['type'], 'no_warranty'); ?>><?php esc_html_e('No Warranty', 'vegavend-merchant-connector'); ?></option>
        <option value="included_warranty" <?php selected($warranty_policy['type'], 'included_warranty'); ?>><?php esc_html_e('Warranty Included', 'vegavend-merchant-connector'); ?></option>
        <option value="addon_warranty" <?php selected($warranty_policy['type'], 'addon_warranty'); ?>><?php esc_html_e('Warranty Add-On (Coming Soon!)', 'vegavend-merchant-connector'); ?></option>
    </select><br>
    <div>
        <label for="warranty_policy_length" style="margin-top: 10px; margin-bottom: 10px;"><?php esc_html_e('Warranty Length', 'vegavend-merchant-connector'); ?></label>
        <select id="warranty_policy_length" name="warranty_policy_length">
            <option value="limited" <?php selected($warranty_policy['length'], 'limited'); ?>><?php esc_html_e('Limited', 'vegavend-merchant-connector'); ?></option>
            <option value="lifetime" <?php selected($warranty_policy['length'], 'lifetime'); ?>><?php esc_html_e('Lifetime', 'vegavend-merchant-connector'); ?></option>
        </select><br>
    </div>
    <div>
        <label for="warranty_policy_length_value" style="margin-top: 10px; margin-bottom: 10px;"><?php esc_html_e('Warranty Length Value', 'vegavend-merchant-connector'); ?></label>
        <input type="text" id="warranty_policy_length_value" name="warranty_policy_length_value" value="<?php echo esc_attr($warranty_policy['length_value']); ?>"><br>
    </div>
    <div>
        <label for="warranty_policy_length_duration" style="margin-top: 10px; margin-bottom: 10px;"><?php esc_html_e('Warranty Length Duration', 'vegavend-merchant-connector'); ?></label>
        <select id="warranty_policy_length_duration" name="warranty_policy_length_duration">
            <option value="days" <?php selected($warranty_policy['length_duration'], 'days'); ?>><?php esc_html_e('Days', 'vegavend-merchant-connector'); ?></option>
            <option value="weeks" <?php selected($warranty_policy['length_duration'], 'weeks'); ?>><?php esc_html_e('Weeks', 'vegavend-merchant-connector'); ?></option>
            <option value="months" <?php selected($warranty_policy['length_duration'], 'months'); ?>><?php esc_html_e('Months', 'vegavend-merchant-connector'); ?></option>
            <option value="years" <?php selected($warranty_policy['length_duration'], 'years'); ?>><?php esc_html_e('Years', 'vegavend-merchant-connector'); ?></option>
        </select><br>
    </div>
    <label for="warranty_policy_reasons"><?php esc_html_e('Warranty Reasons', 'vegavend-merchant-connector'); ?></label>
    <div id="warranty_policy_reasons">
        <?php
        $reasons = array(
            'item_has_not_been_received' => __('Item has not been received', 'vegavend-merchant-connector'),
            'item_did_not_meet_my_expectation' => __('Item did not meet my expectation', 'vegavend-merchant-connector'),
            'i_received_an_item_that_does_not_match_its_description' => __('I received an item that does not match its description', 'vegavend-merchant-connector'),
            'i_received_an_incorrect_item' => __('I received an incorrect item', 'vegavend-merchant-connector'),
            'i_received_a_damaged_item' => __('I received a damaged item', 'vegavend-merchant-connector'),
            'i_received_a_defective_item' => __('I received a defective item', 'vegavend-merchant-connector')
        );
        foreach ($reasons as $value => $label) {
            $checked = in_array($value, $warranty_policy['reasons']) ? 'checked' : '';
            echo '<label for="warranty_policy_reasons_' . esc_attr($value) . '" style="margin-bottom: 10px; width: 100%;"><input type="checkbox" id="warranty_policy_reasons_' . esc_attr($value) . '" name="warranty_policy_reasons[]" value="' . esc_attr($value) . '" ' . esc_attr($checked) . '> ' . esc_html($label) . '</label>';
        }
        ?>
    </div>

    <h2><?php esc_html_e('Basic Shipping', 'vegavend-merchant-connector'); ?></h2>
    <label for="shipping_methods"><?php esc_html_e('Shipping Methods', 'vegavend-merchant-connector'); ?></label>
    <div id="shipping_methods_container">
        <?php if (empty($shipping_methods)): ?>
            <div class="shipping-method" data-index="0">
                <label for="shipping_zone_0" style="margin-top: 10px; margin-bottom: 10px;"><?php esc_html_e('Zone', 'vegavend-merchant-connector'); ?></label>
                <select id="shipping_zone_0" name="shipping_methods[0][zone]" class="shipping-zone-select" style="margin-top: 10px; margin-bottom: 10px;" disabled>
                    <option value="UK"><?php esc_html_e('UK', 'vegavend-merchant-connector'); ?></option>
                    <option value="Europe"><?php esc_html_e('Europe', 'vegavend-merchant-connector'); ?></option>
                    <option value="North America"><?php esc_html_e('North America', 'vegavend-merchant-connector'); ?></option>
                    <option value="Asia"><?php esc_html_e('Asia', 'vegavend-merchant-connector'); ?></option>
                    <option value="Oceania"><?php esc_html_e('Oceania', 'vegavend-merchant-connector'); ?></option>
                </select><br>
                <label for="shipping_method_0" style="margin-top: 10px; margin-bottom: 10px;"><?php esc_html_e('Method', 'vegavend-merchant-connector'); ?></label>
                <select id="shipping_method_0" name="shipping_methods[0][method]" class="shipping-method-select" style="margin-top: 10px; margin-bottom: 10px;" disabled>
                    <option value="flat_rate"><?php esc_html_e('Flat Rate', 'vegavend-merchant-connector'); ?></option>
                    <option value="free_shipping"><?php esc_html_e('Free Shipping', 'vegavend-merchant-connector'); ?></option>
                </select><br>
                <div class="shipping-method-details">
                    <label for="shipping_cost_0"><?php esc_html_e('Cost', 'vegavend-merchant-connector'); ?></label>
                    <input type="text" id="shipping_cost_0" name="shipping_methods[0][cost]" value="" readonly><br>
                </div>
                <button type="button" class="remove-shipping-method" style="display: none;"><?php esc_html_e('Remove', 'vegavend-merchant-connector'); ?></button>
            </div>
        <?php else: ?>
            <?php foreach ($shipping_methods as $index => $method): ?>
                <div class="shipping-method" data-index="<?php echo esc_attr($index); ?>">
                    <label for="shipping_zone_<?php echo esc_attr($index); ?>" style="margin-top: 10px; margin-bottom: 10px;"><?php esc_html_e('Zone', 'vegavend-merchant-connector'); ?></label>
                    <select id="shipping_zone_<?php echo esc_attr($index); ?>" name="shipping_methods[<?php echo esc_attr($index); ?>][zone]" class="shipping-zone-select" style="margin-top: 10px; margin-bottom: 10px;" disabled>
                        <option value="UK" <?php selected($method['zone'], 'UK'); ?>><?php esc_html_e('UK', 'vegavend-merchant-connector'); ?></option>
                        <option value="Europe" <?php selected($method['zone'], 'Europe'); ?>><?php esc_html_e('Europe', 'vegavend-merchant-connector'); ?></option>
                        <option value="North America" <?php selected($method['zone'], 'North America'); ?>><?php esc_html_e('North America', 'vegavend-merchant-connector'); ?></option>
                        <option value="Asia" <?php selected($method['zone'], 'Asia'); ?>><?php esc_html_e('Asia', 'vegavend-merchant-connector'); ?></option>
                        <option value="Oceania" <?php selected($method['zone'], 'Oceania'); ?>><?php esc_html_e('Oceania', 'vegavend-merchant-connector'); ?></option>
                    </select><br>
                    <label for="shipping_method_<?php echo esc_attr($index); ?>" style="margin-top: 10px; margin-bottom: 10px;"><?php esc_html_e('Method', 'vegavend-merchant-connector'); ?></label>
                    <select id="shipping_method_<?php echo esc_attr($index); ?>" name="shipping_methods[<?php echo esc_attr($index); ?>][method]" class="shipping-method-select" style="margin-top: 10px; margin-bottom: 10px;" disabled>
                        <option value="flat_rate" <?php selected($method['method'], 'flat_rate'); ?>><?php esc_html_e('Flat Rate', 'vegavend-merchant-connector'); ?></option>
                        <option value="free_shipping" <?php selected($method['method'], 'free_shipping'); ?>><?php esc_html_e('Free Shipping', 'vegavend-merchant-connector'); ?></option>
                    </select><br>
                    <div class="shipping-method-details">
                        <label for="shipping_cost_<?php echo esc_attr($index); ?>"><?php esc_html_e('Cost', 'vegavend-merchant-connector'); ?></label>
                        <input type="text" id="shipping_cost_<?php echo esc_attr($index); ?>" name="shipping_methods[<?php echo esc_attr($index); ?>][cost]" value="<?php echo esc_attr($method['cost']); ?>" readonly><br>
                    </div>
                    <button type="button" class="remove-shipping-method" style="display: none;"><?php esc_html_e('Remove', 'vegavend-merchant-connector'); ?></button>
                </div>
            <?php endforeach; ?>
        <?php endif; ?>
    </div>
    <button type="button" id="add_shipping_method" style="display: none;"><?php esc_html_e('Add Shipping Method', 'vegavend-merchant-connector'); ?></button>

    <div style="display: flex; justify-content: flex-end; max-width: 475px;">
        <a href="<?php echo esc_url(Vegavend_API_Config::get_base_url() . '/dashboard/settings/shipping/#/'); ?>" class="button" target="_blank">
            <?php esc_html_e('Manage Shipping', 'vegavend-merchant-connector'); ?> <span class="dashicons dashicons-external" style="font-size: 16px; vertical-align: middle;"></span>
        </a>
    </div><br><br>

    <h2><?php esc_html_e('Social Profiles', 'vegavend-merchant-connector'); ?></h2>
    <?php foreach ($social_profiles as $profile => $value): ?>
        <div style="margin-top: 10px;">
            <label for="<?php echo esc_attr($profile); ?>"><?php echo esc_html(ucfirst($profile)); ?></label>
            <input type="text" id="<?php echo esc_attr($profile); ?>" name="social_profiles[<?php echo esc_attr($profile); ?>]" value="<?php echo esc_attr($value); ?>" style="width: 400px;">
        </div>
    <?php endforeach; ?>

    <div style="margin-top: 30px;"></div>

    <h2><?php esc_html_e('Store SEO', 'vegavend-merchant-connector'); ?></h2>
    <div style="display: flex; justify-content: flex-end; max-width: 475px; margin-bottom: 1px;">
        <span id="seo_title_counter">0/57</span>
    </div>
    <label for="store_seo_title"><?php esc_html_e('SEO Title', 'vegavend-merchant-connector'); ?> <span class="dashicons dashicons-editor-help" title="<?php esc_attr_e('Enter a concise and descriptive title for your store, up to 57 characters.', 'vegavend-merchant-connector'); ?>"></span></label>
    <input type="text" id="store_seo_title" name="store_seo_title" maxlength="57" value="<?php echo esc_attr(get_option('vegavend_store_seo_title')); ?>"><br>
    <div style="display: flex; justify-content: flex-end; max-width: 475px; margin-bottom: 1px; margin-top: 10px;">
        <span id="seo_meta_description_counter">0/156</span>
    </div>
    <label for="store_seo_meta_description"><?php esc_html_e('Meta Description', 'vegavend-merchant-connector'); ?> <span class="dashicons dashicons-editor-help" title="<?php esc_attr_e('Provide a brief description of your store, up to 156 characters.', 'vegavend-merchant-connector'); ?>"></span></label>
    <textarea id="store_seo_meta_description" name="store_seo_meta_description" maxlength="156"><?php echo esc_textarea(get_option('vegavend_store_seo_meta_description')); ?></textarea>
    <div style="display: flex; justify-content: flex-end; max-width: 475px; margin-bottom: 1px; margin-top: 10px;">
        <span id="seo_keywords_counter">0/55</span>
    </div>
    <label for="store_seo_keywords"><?php esc_html_e('Keywords', 'vegavend-merchant-connector'); ?> <span class="dashicons dashicons-editor-help" title="<?php esc_attr_e('Enter keywords that are relevant to your store, up to 5 words separated by a comma.', 'vegavend-merchant-connector'); ?>"></span></label>
    <textarea id="store_seo_keywords" name="store_seo_keywords" maxlength="55"><?php echo esc_textarea(get_option('vegavend_store_seo_keywords')); ?></textarea>

    <div style="margin-top: 30px;"></div>

    <h2><?php esc_html_e('Payments', 'vegavend-merchant-connector'); ?></h2>
    <?php $payment_settings_url = Vegavend_API_Config::get_base_url() . '/dashboard/settings/payment/'; ?>
    <div style="display: flex; align-items: center; max-width: 475px;">
        <div style="margin-left: 100px;">
            <?php if ($stripe_connected === 'yes'): ?>
                <span style="color: green;">●</span> <?php esc_html_e('Connected', 'vegavend-merchant-connector'); ?> (<?php echo esc_html(ucfirst($payment_method)); ?>)
            <?php else: ?>
                <span style="color: red;">●</span> <?php esc_html_e('Not Connected', 'vegavend-merchant-connector'); ?>
            <?php endif; ?>
        </div>
        <div style="margin-left: auto;">
            <?php if ($stripe_connected === 'yes'): ?>
                <a href="<?php echo esc_url($payment_settings_url); ?>" class="button" style="margin-left: 10px;" target="_blank">
                    <?php esc_html_e('Manage', 'vegavend-merchant-connector'); ?> <span class="dashicons dashicons-external" style="font-size: 16px; vertical-align: middle;"></span>
                </a>
            <?php else: ?>
                <a href="<?php echo esc_url($payment_settings_url); ?>" class="button" style="margin-left: 10px;" target="_blank">
                    <?php esc_html_e('Connect Now', 'vegavend-merchant-connector'); ?> <span class="dashicons dashicons-external" style="font-size: 16px; vertical-align: middle;"></span>
                </a>
            <?php endif; ?>
        </div>
    </div><br>

    <div style="margin-top: 30px;"></div>

    <h2><?php esc_html_e('Account Verification', 'vegavend-merchant-connector'); ?></h2>
    <?php $verification_url = Vegavend_API_Config::get_base_url() . '/dashboard/settings/verification/'; ?>
    <label for="identification_verified" style="margin-left: 100px; width: 300px;">
        <?php
        switch ($verification_statuses['identification']) {
            case 'Approved':
                echo '<span style="color: green;">●</span> ' . esc_html__('Identification - Verified', 'vegavend-merchant-connector');
                break;
            case 'Pending':
                echo '<span style="color: orange;">●</span> ' . esc_html__('Identification - Pending', 'vegavend-merchant-connector');
                break;
            case 'Cancelled':
                echo '<span style="color: red;">●</span> ' . esc_html__('Identification - Cancelled', 'vegavend-merchant-connector');
                break;
            default:
                echo '<span style="color: gray;">●</span> ' . esc_html__('Identification - Not Verified', 'vegavend-merchant-connector');
                break;
        }
        ?>
    </label><br>
    <label for="address_verified" style="margin-left: 100px; width: 300px;">
        <?php
        switch ($verification_statuses['address']) {
            case 'Approved':
                echo '<span style="color: green;">●</span> ' . esc_html__('Address - Verified', 'vegavend-merchant-connector');
                break;
            case 'Pending':
                echo '<span style="color: orange;">●</span> ' . esc_html__('Address - Pending', 'vegavend-merchant-connector');
                break;
            case 'Cancelled':
                echo '<span style="color: red;">●</span> ' . esc_html__('Address - Cancelled', 'vegavend-merchant-connector');
                break;
            default:
                echo '<span style="color: gray;">●</span> ' . esc_html__('Address - Not Verified', 'vegavend-merchant-connector');
                break;
        }
        ?>
    </label><br>
    <label for="company_id_verified" style="margin-left: 100px; width: 300px;">
        <?php
        switch ($verification_statuses['company_registration']) {
            case 'Approved':
                echo '<span style="color: green;">●</span> ' . esc_html__('Company ID - Verified', 'vegavend-merchant-connector');
                break;
            case 'Pending':
                echo '<span style="color: orange;">●</span> ' . esc_html__('Company ID - Pending', 'vegavend-merchant-connector');
                break;
            case 'Cancelled':
                echo '<span style="color: red;">●</span> ' . esc_html__('Company ID - Cancelled', 'vegavend-merchant-connector');
                break;
            default:
                echo '<span style="color: gray;">●</span> ' . esc_html__('Company ID - Not Verified', 'vegavend-merchant-connector');
                break;
        }
        ?>
    </label><br>
    <label for="vat_number_verified" style="margin-left: 100px; width: 300px;">
        <?php
        switch ($verification_statuses['vat_number']) {
            case 'Approved':
                echo '<span style="color: green;">●</span> ' . esc_html__('UK VAT Number - Verified', 'vegavend-merchant-connector');
                break;
            case 'Pending':
                echo '<span style="color: orange;">●</span> ' . esc_html__('UK VAT Number - Pending', 'vegavend-merchant-connector');
                break;
            case 'Cancelled':
                echo '<span style="color: red;">●</span> ' . esc_html__('UK VAT Number - Cancelled', 'vegavend-merchant-connector');
                break;
            default:
                echo '<span style="color: gray;">●</span> ' . esc_html__('UK VAT Number - Not Verified', 'vegavend-merchant-connector');
                break;
        }
        ?>
    </label><br>
    <?php if ($verification_statuses['identification'] !== 'Approved' || $verification_statuses['address'] !== 'Approved' || $verification_statuses['company_registration'] !== 'Approved' || $verification_statuses['vat_number'] !== 'Approved'): ?>
        <div style="display: flex; justify-content: flex-end; max-width: 475px;">
            <a href="<?php echo esc_url($verification_url); ?>" class="button" target="_blank">
                <?php esc_html_e('Verify Now', 'vegavend-merchant-connector'); ?> <span class="dashicons dashicons-external" style="font-size: 16px; vertical-align: middle;"></span>
            </a>
        </div><br><br>
    <?php endif; ?>

    <div style="margin-top: 30px;"></div>

    <div style="display: flex; justify-content: flex-end; max-width: 475px;">
        <button type="submit"><?php esc_html_e('Update Account', 'vegavend-merchant-connector'); ?></button>
    </div>
</form>