<?php
if (!defined('ABSPATH')) exit;

require_once plugin_dir_path(__FILE__) . 'vegavend_account_page.php';

class Vegavend_Admin_Menu {

    public function __construct() {
        add_action('admin_menu', array($this, 'vegavend_add_admin_menu'));
        add_action('admin_menu', array($this, 'vegavend_add_issues_count_to_menu'), 99);
        add_action('admin_enqueue_scripts', array($this, 'vegavend_enqueue_admin_styles'));
    }

    // Add Admin Menu
    public function vegavend_add_admin_menu() {
        $svg_icon = '';
        $icon_path = VEGAVEND_PLUGIN_URL . '/assets/images/vegavend-emoticon.svg';
        
        $response = wp_remote_get($icon_path);
        if (!is_wp_error($response)) {
            $svg_icon = wp_remote_retrieve_body($response);
        }

        $icon_url = 'data:image/svg+xml;base64,' . base64_encode($svg_icon);

        if (get_option('vegavend_store_id')) {
            add_menu_page(
                __('VegaVend', 'vegavend-merchant-connector'),
                __('VegaVend', 'vegavend-merchant-connector'),
                'manage_options',
                'vegavend-connector',
                array($this, 'vegavend_status_page'),
                $icon_url,
                56
            );

            add_submenu_page(
                'vegavend-connector',
                esc_html__('Account Status', 'vegavend-merchant-connector'),
                esc_html__('Status', 'vegavend-merchant-connector'),
                'manage_options',
                'vegavend-status',
                array($this, 'vegavend_status_page')
            );
            add_submenu_page(
                'vegavend-connector',
                esc_html__('Product Issues', 'vegavend-merchant-connector'),
                esc_html__('Issues', 'vegavend-merchant-connector'),
                'manage_options',
                'vegavend-product-issues', // This is the slug for the product issues page
                array('Vegavend_Product_Issues_Page', 'render_issues_page')
            );
            add_submenu_page(
                'vegavend-connector',
                esc_html__('Account', 'vegavend-merchant-connector'),
                esc_html__('Account', 'vegavend-merchant-connector'),
                'manage_options',
                'vegavend-account',
                array($this, 'vegavend_account_page')
            );
        } else {
            add_menu_page(
                __('VegaVend', 'vegavend-merchant-connector'),
                __('VegaVend', 'vegavend-merchant-connector'),
                'manage_options',
                'vegavend-connector',
                array($this, 'vegavend_settings_page'),
                $icon_url,
                56
            );
        }

        add_submenu_page(
            'vegavend-connector',
            esc_html__('Account Settings', 'vegavend-merchant-connector'),
            esc_html__('Settings', 'vegavend-merchant-connector'),
            'manage_options',
            'vegavend-settings',
            array($this, 'vegavend_settings_page')
        );
        add_submenu_page(
            'vegavend-connector',
            esc_html__('Support', 'vegavend-merchant-connector'),
            esc_html__('Support', 'vegavend-merchant-connector'),
            'manage_options',
            'vegavend-support',
            array($this, 'vegavend_support_page')
        );

        // Remove the top-level menu item from the submenu
        remove_submenu_page('vegavend-connector', 'vegavend-connector');
    }

    public function vegavend_add_issues_count_to_menu() {
        $store_id = get_option('vegavend_store_id');
        $product_issues_data = Vegavend_Product_Issues_Page::get_product_issues_data($store_id);
        $issues_count = count($product_issues_data);

        global $submenu;
        if (isset($submenu['vegavend-connector'])) {
            foreach ($submenu['vegavend-connector'] as $key => $menu_item) {
                if ($menu_item[2] === 'vegavend-product-issues') {
                    $submenu['vegavend-connector'][$key][0] .= sprintf(
                        ' <span class="update-plugins count-%1$d"><span class="plugin-count">%1$d</span></span>',
                        $issues_count
                    );
                    break;
                }
            }
        }
    }

    public function vegavend_settings_page() {
        $settings_page = new Vegavend_Settings_Page();
        $settings_page->vegavend_settings_page();
    }

    public function vegavend_status_page() {
        $status_page = new Vegavend_Status_Page();
        $status_page->vegavend_status_page();
    }

    public function vegavend_support_page() {
        $support_page = new Vegavend_Support_Page();
        $support_page->vegavend_support_page();
    }

    public function vegavend_issues_page() {
        $issues_page = new Vegavend_Product_Issues_Page();
        $issues_page->render_issues_page();
    }

    public function vegavend_account_page() {
        $account_page = Vegavend_Account_Page::get_instance();
        $account_page->render_account_page();
    }

    public function vegavend_enqueue_admin_styles() {
        // Remove the line that enqueues the non-existent CSS file
        // wp_enqueue_style('vegavend-admin-styles', VEGAVEND_PLUGIN_URL . '/assets/css/admin.css');
        
        // Remove the line that enqueues the non-existent JavaScript file
        // wp_enqueue_script('vegavend-admin-script', VEGAVEND_PLUGIN_URL . '/admin/assets/js/admin-script.js', array('jquery'), '1.0.0', true);
    }
}

new Vegavend_Admin_Menu();
?>