<?php
if ( ! defined( 'ABSPATH' ) ) exit;

require_once plugin_dir_path(__FILE__) . 'vegavend_api_config.php';

class Vegavend_Product_Issues_Page {

    public function __construct() {
        // Hook into WordPress actions
        add_action('add_meta_boxes', array($this, 'add_product_issues_meta_box'));
    }

    // Render the issues page in the admin area
    public static function render_issues_page() {
        if (!current_user_can('manage_options')) {
            wp_die(esc_html__('Sorry, you are not allowed to access this page.', 'vegavend-merchant-connector'));
        }

        $store_id = get_option('vegavend_store_id');
        if (!$store_id) {
            ?>
            <div class="wrap">
                <h1><?php esc_html_e('VegaVend Product Issues', 'vegavend-merchant-connector'); ?></h1>
                <p><?php esc_html_e('Please connect your store to VegaVend to view product issues.', 'vegavend-merchant-connector'); ?></p>
            </div>
            <?php
            return;
        }

        $product_issues_data = self::get_product_issues_data($store_id);
        $total_count = count($product_issues_data);
        $published_count = count(array_filter($product_issues_data, function($product) {
            return $product['status'] === 'publish';
        }));

        // Pagination setup
        $per_page = 20;
        $current_page = isset($_GET['paged']) ? max(1, intval($_GET['paged'])) : 1;
        $total_pages = ceil($total_count / $per_page);
        $offset = ($current_page - 1) * $per_page;
        $paged_data = array_slice($product_issues_data, $offset, $per_page);

        $status = isset($_GET['status']) ? sanitize_text_field(wp_unslash($_GET['status'])) : '';

        ?>
        <div class="wrap">
            <h1><?php esc_html_e('VegaVend Product Issues', 'vegavend-merchant-connector'); ?></h1>
            <br>
            <?php if (empty($product_issues_data)) : ?>
                <p><strong><?php esc_html_e('Congratulations! You currently have no products with issues on VegaVend.', 'vegavend-merchant-connector'); ?></strong></p>
            <?php else : ?>
                <p><strong><?php esc_html_e('The following products have been found to have issues that may prevent them from being published on VegaVend. You can navigate to the product and you will find the issues listed and colour coded.', 'vegavend-merchant-connector'); ?></strong></p>
                <ul class="subsubsub">
                    <li class="all"><a href="?page=vegavend-product-issues&_wpnonce=<?php echo esc_attr(wp_create_nonce('vegavend_product_issues_nonce')); ?>" class="current"><?php esc_html_e('All', 'vegavend-merchant-connector'); ?> <span class="count">(<?php echo esc_html($total_count); ?>)</span></a> |</li>
                    <li class="publish"><a href="?page=vegavend-product-issues&status=publish&_wpnonce=<?php echo esc_attr(wp_create_nonce('vegavend_product_issues_nonce')); ?>"><?php esc_html_e('Published', 'vegavend-merchant-connector'); ?> <span class="count">(<?php echo esc_html($published_count); ?>)</span></a></li>
                </ul>
                <?php
                // Pagination links at the top
                if ($total_pages > 1) {
                    $page_links = paginate_links(array(
                        'base' => add_query_arg('paged', '%#%'),
                        'format' => '',
                        'prev_text' => esc_html__('&lsaquo;', 'vegavend-merchant-connector'),
                        'next_text' => esc_html__('&rsaquo;', 'vegavend-merchant-connector'),
                        'total' => $total_pages,
                        'current' => $current_page,
                        'type' => 'array',
                    ));
                    if ($page_links) {
                        echo '<div class="tablenav top"><div class="tablenav-pages">';
                        // translators: %s: number of items
                        echo '<span class="displaying-num">' . esc_html(sprintf(_n('%s item', '%s items', $total_count, 'vegavend-merchant-connector'), number_format_i18n($total_count))) . '</span>';
                        echo '<span class="pagination-links">';
                        echo '<a class="first-page button ' . ($current_page == 1 ? 'disabled' : '') . '" href="' . esc_url(add_query_arg('paged', 1)) . '" style="margin-right: 5px;">&laquo;</a>';
                        echo '<a class="prev-page button ' . ($current_page == 1 ? 'disabled' : '') . '" href="' . esc_url(add_query_arg('paged', max(1, $current_page - 1))) . '" style="margin-right: 5px;">&lsaquo;</a>';
                        echo '<span class="paging-input">';
                        echo '<form id="pagination-form" method="get" action="" style="display:inline;">';
                        echo '<input type="hidden" name="page" value="vegavend-product-issues">';
                        if (isset($_GET['status'])) {
                            echo '<input type="hidden" name="status" value="' . esc_attr(sanitize_text_field(wp_unslash($_GET['status']))) . '">';
                        }
                        echo '<input class="current-page" id="current-page-selector" type="text" name="paged" value="' . esc_attr($current_page) . '" size="1" aria-describedby="table-paging">';
                        echo ' ' . esc_html__('of', 'vegavend-merchant-connector') . ' <span class="total-pages">' . esc_html($total_pages) . '</span>';
                        echo '</form>';
                        echo '</span>';
                        echo '<a class="next-page button ' . ($current_page == $total_pages ? 'disabled' : '') . '" href="' . esc_url(add_query_arg('paged', min($total_pages, $current_page + 1))) . '" style="margin-left: 5px;">&rsaquo;</a>';
                        echo '<a class="last-page button ' . ($current_page == $total_pages ? 'disabled' : '') . '" href="' . esc_url(add_query_arg('paged', $total_pages)) . '" style="margin-left: 5px;">&raquo;</a>';
                        echo '</span></div></div>';
                    }
                }
                ?>
                <table class="wp-list-table widefat fixed striped">
                    <thead>
                        <tr>
                            <th style="width: 5%; text-align: center;"><span class="dashicons dashicons-format-image"></span></th>
                            <th style="width: 35%;"><?php esc_html_e('Product Name', 'vegavend-merchant-connector'); ?></th>
                            <th style="width: 10%;"><?php esc_html_e('Product ID', 'vegavend-merchant-connector'); ?></th>
                            <th style="width: 10%;"><?php esc_html_e('VegaVend PID', 'vegavend-merchant-connector'); ?></th>
                            <th style="width: 10%;"><?php esc_html_e('Status', 'vegavend-merchant-connector'); ?></th>
                            <th style="width: 10%;"><?php esc_html_e('Number of Issues', 'vegavend-merchant-connector'); ?></th>
                            <th style="width: 20%;"><?php esc_html_e('Actions', 'vegavend-merchant-connector'); ?></th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (!empty($paged_data)) : ?>
                            <?php foreach ($paged_data as $product) : ?>
                                <?php if (is_array($product) && (!$status || $status === $product['status'])) : ?>
                                    <tr>
                                        <td style="text-align: center;"><?php echo get_the_post_thumbnail($product['original_id'], array(40, 40)); ?></td>
                                        <td><a href="<?php echo esc_url(get_edit_post_link($product['original_id'])); ?>"><strong><?php echo esc_html($product['name']); ?></strong></a></td>
                                        <td><?php echo esc_html($product['original_id']); ?></td>
                                        <td><?php echo esc_html($product['id']); ?></td>
                                        <td><?php echo esc_html($product['status'] === 'publish' ? __('Published', 'vegavend-merchant-connector') : ucfirst($product['status'])); ?></td>
                                        <td><?php echo esc_html($product['issues_count']); ?></td>
                                        <td>
                                            <a href="<?php echo esc_url(get_edit_post_link($product['original_id'])); ?>" class="button"><?php esc_html_e('Edit Product', 'vegavend-merchant-connector'); ?></a>
                                        </td>
                                    </tr>
                                <?php endif; ?>
                            <?php endforeach; ?>
                        <?php else : ?>
                            <tr>
                                <td colspan="7"><?php esc_html_e('No product issues found.', 'vegavend-merchant-connector'); ?></td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                    <tfoot>
                        <tr>
                            <th style="width: 5%; text-align: center;"><span class="dashicons dashicons-format-image"></span></th>
                            <th style="width: 35%;"><?php esc_html_e('Product Name', 'vegavend-merchant-connector'); ?></th>
                            <th style="width: 10%;"><?php esc_html_e('Product ID', 'vegavend-merchant-connector'); ?></th>
                            <th style="width: 10%;"><?php esc_html_e('VegaVend PID', 'vegavend-merchant-connector'); ?></th>
                            <th style="width: 10%;"><?php esc_html_e('Status', 'vegavend-merchant-connector'); ?></th>
                            <th style="width: 10%;"><?php esc_html_e('Number of Issues', 'vegavend-merchant-connector'); ?></th>
                            <th style="width: 20%;"><?php esc_html_e('Actions', 'vegavend-merchant-connector'); ?></th>
                        </tr>
                    </tfoot>
                </table>
                <?php
                // Pagination links at the bottom
                if ($total_pages > 1) {
                    $page_links = paginate_links(array(
                        'base' => add_query_arg('paged', '%#%'),
                        'format' => '',
                        'prev_text' => esc_html__('&lsaquo;', 'vegavend-merchant-connector'),
                        'next_text' => esc_html__('&rsaquo;', 'vegavend-merchant-connector'),
                        'total' => $total_pages,
                        'current' => $current_page,
                        'type' => 'array',
                    ));
                    if ($page_links) {
                        echo '<div class="tablenav bottom"><div class="tablenav-pages">';
                        // translators: %s: number of items
                        echo '<span class="displaying-num">' . esc_html(sprintf(_n('%s item', '%s items', $total_count, 'vegavend-merchant-connector'), number_format_i18n($total_count))) . '</span>';
                        echo '<span class="pagination-links">';
                        echo '<a class="first-page button ' . ($current_page == 1 ? 'disabled' : '') . '" href="' . esc_url(add_query_arg('paged', 1)) . '" style="margin-right: 5px;">&laquo;</a>';
                        echo '<a class="prev-page button ' . ($current_page == 1 ? 'disabled' : '') . '" href="' . esc_url(add_query_arg('paged', max(1, $current_page - 1))) . '" style="margin-right: 5px;">&lsaquo;</a>';
                        echo '<span class="paging-input">';
                        echo '<span class="current-page">' . esc_html($current_page) . '</span>';
                        echo ' ' . esc_html__('of', 'vegavend-merchant-connector') . ' <span class="total-pages">' . esc_html($total_pages) . '</span>';
                        echo '</span>';
                        echo '<a class="next-page button ' . ($current_page == $total_pages ? 'disabled' : '') . '" href="' . esc_url(add_query_arg('paged', min($total_pages, $current_page + 1))) . '" style="margin-left: 5px;">&rsaquo;</a>';
                        echo '<a class="last-page button ' . ($current_page == $total_pages ? 'disabled' : '') . '" href="' . esc_url(add_query_arg('paged', $total_pages)) . '" style="margin-left: 5px;">&raquo;</a>';
                        echo '</span></div></div>';
                    }
                }
                ?>
            <?php endif; ?>
        </div>
        <?php
    }

    // Render product issues in a list format
    public static function render_product_issues($product_issues_data) {
        echo '<p>' . esc_html__('Here are the current product issues in your VegaVend Store:', 'vegavend-merchant-connector') . '</p>';
        if (!empty($product_issues_data)) {
            ?>
            <ul class="vegavend-product-issues">
                <?php foreach ($product_issues_data as $issue) : ?>
                    <li>
                        <strong><?php echo esc_html($issue['name']); ?></strong> - <?php echo esc_html($issue['status']); ?>
                        <ul>
                            <?php if (isset($issue['issues']) && is_array($issue['issues'])) : ?>
                                <?php foreach ($issue['issues'] as $reason) : ?>
                                    <li><?php echo esc_html($reason); ?></li>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </ul>
                    </li>
                <?php endforeach; ?>
            </ul>
            <?php
        } else {
            echo '<p>' . esc_html__('No product issues found.', 'vegavend-merchant-connector') . '</p>';
        }
    }

    // Add the product issues meta box to the product edit screen
    public function add_product_issues_meta_box() {
        add_meta_box(
            'vegavend_product_issues',
            __('Product Issues', 'vegavend-merchant-connector'),
            array($this, 'display_product_issues_meta_box'),
            'product',
            'side',
            'default'
        );
    }

    // Display the product issues meta box
    public function display_product_issues_meta_box($post) {
        wp_nonce_field('vegavend_product_issues_meta_box', 'vegavend_product_issues_meta_box_nonce'); // Add nonce for security
        $store_id = get_option('vegavend_store_id');
        $product_issues_data = self::get_product_issues_data($store_id);
        if (!empty($product_issues_data)) {
            foreach ($product_issues_data as $product) {
                if (is_array($product) && isset($product['original_id']) && $product['original_id'] == $post->ID) { // Fix comparison logic and add array check
                    echo '<ul>';
                    if (isset($product['issues']) && is_array($product['issues'])) {
                        foreach ($product['issues'] as $issue) {
                            echo '<li>' . esc_html($issue) . '</li>';
                        }
                    }
                    echo '</ul>';
                    return;
                }
            }
        }
        echo '<p><span style="color: green;">&#9679;</span> ' . esc_html__('No issues found for this product.', 'vegavend-merchant-connector') . '</p>'; // Add green dot
    }

    // Retrieve product issues data from the VegaVend API
    public static function get_product_issues_data($store_id) {
        $url = Vegavend_API_Config::get_product_issues_url();
        $body = wp_json_encode(array('store_id' => sanitize_text_field($store_id)));
        $args = array(
            'method' => 'POST',
            'body' => $body,
            'headers' => array(
                'X-API-Key' => Vegavend_API_Config::get_api_key(),
                'Content-Type' => 'application/json',
            ),
            'timeout' => 60,
            'redirection' => 10,
        );
        $response = wp_remote_post($url, $args);
        if (is_wp_error($response)) {
            return array();
        }
        $data = json_decode(wp_remote_retrieve_body($response), true);

        // Format the product issues data
        $formatted_data = array();
        if (!empty($data['data']) && is_array($data['data'])) {
            foreach ($data['data'] as $product) {
                $formatted_data[] = array(
                    'id' => sanitize_text_field($product['id']),
                    'original_id' => sanitize_text_field($product['original_id']), // Add original product ID
                    'name' => sanitize_text_field($product['name']),
                    'status' => sanitize_text_field($product['status']),
                    'issues_count' => isset($product['issues_count']) ? intval($product['issues_count']) : 0,
                    'issues' => isset($product['issues']) ? array_map('sanitize_text_field', $product['issues']) : array(),
                );
            }
        }
        return $formatted_data;
    }
}

new Vegavend_Product_Issues_Page();