<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class Vegavend_Settings_Page {

    public function __construct() {
        add_action('admin_enqueue_scripts', array($this, 'vegavend_enqueue_scripts'));
        add_action('wp_ajax_vegavend_check_store_id', array($this, 'vegavend_check_store_id'));
        add_action('wp_ajax_vegavend_delete_store_id', array($this, 'vegavend_delete_store_id'));
        add_action('wp_ajax_vegavend_get_store_id', array($this, 'vegavend_get_store_id'));
        add_action('admin_init', array($this, 'vegavend_register_settings'));
    }

    public function vegavend_register_settings() {
        register_setting('vegavend_options_group', 'vegavend_store_id', array(
            'type' => 'string',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        register_setting('vegavend_general_options_group', 'vegavend_sync_setting', array(
            'type' => 'string',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        register_setting('vegavend_general_options_group', 'vegavend_sync_via_cron', array(
            'type' => 'boolean',
            'sanitize_callback' => 'rest_sanitize_boolean',
        ));
    }

    public function vegavend_settings_page() {
        $store_id = get_option('vegavend_store_id'); // Unmasked store ID
        $masked_store_id = $this->vegavend_mask_store_id($store_id); // Masked store ID for display
        $is_connected = $this->vegavend_check_store_id_sync($store_id);
        $base_url = Vegavend_API_Config::get_base_url();
        $tasks = $this->get_tasks_status($store_id);
        $all_tasks_completed = $this->are_all_tasks_completed($tasks);
        $sync_setting = get_option('vegavend_sync_setting', 'sync_selected'); // Default to "Only Sync Products I Set"
        $sync_via_cron = get_option('vegavend_sync_via_cron', false);
        $account_page_url = admin_url('admin.php?page=vegavend_account_page'); // URL to the account page
        ?>
        <div class="wrap">
            <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
            <div class="card">
                <div style="float: right; margin-top: 10px;">
                    <p id="vegavend-store-connected" style="color: green; <?php echo $is_connected ? '' : 'display: none;'; ?>">
                        <span style="color: green; font-size: 20px;">●</span> <?php esc_html_e('Store Connected', 'vegavend-merchant-connector'); ?>
                    </p>
                    <p id="vegavend-store-not-connected" style="color: red; <?php echo !$is_connected ? '' : 'display: none;'; ?>">
                        <span style="color: red; font-size: 20px;">●</span> <?php esc_html_e('Store Not Connected', 'vegavend-merchant-connector'); ?>
                    </p>
                </div>
                <form id="vegavend-settings-form" action="options.php" method="post">
                    <?php
                    settings_fields('vegavend_options_group');
                    do_settings_sections('vegavend_options_group');
                    ?>
                    <table class="form-table">
                        <tr valign="top">
                            <th scope="row"><?php esc_html_e('VegaVend Store ID', 'vegavend-merchant-connector'); ?></th>
                            <td>
                                <input type="text" id="vegavend_store_id" name="vegavend_store_id" value="<?php echo esc_attr($masked_store_id); ?>" style="width: 300px;" <?php echo $is_connected ? 'readonly' : ''; ?> />
                                <p class="description"><?php esc_html_e('Enter your VegaVend Store ID to connect your VegaVend account with your website.', 'vegavend-merchant-connector'); ?></p>
                                <p><a target="_blank" href="<?php echo esc_url($base_url . '/dashboard/merchant_integrations/?platform=woo'); ?>"><?php esc_html_e('Find my ID', 'vegavend-merchant-connector'); ?></a></p>
                            </td>
                        </tr>
                    </table>
                    <button type="button" id="vegavend-edit-store-id" class="button button-primary" <?php echo !$is_connected ? 'style="display:none;"' : ''; ?>><?php esc_html_e('Disconnect', 'vegavend-merchant-connector'); ?></button>
                    <?php submit_button(__('Connect', 'vegavend-merchant-connector'), 'primary', 'vegavend-save-store-id', true, array('style' => $is_connected ? 'display:none;' : '')); ?>
                    <?php wp_nonce_field('vegavend_nonce_action', 'vegavend_nonce'); ?>
                </form>
            </div>
            <?php if ($is_connected): ?>
            <div class="card">
                <h2><?php esc_html_e('General Settings', 'vegavend-merchant-connector'); ?></h2>
                <form id="vegavend-general-settings-form" action="options.php" method="post">
                    <?php settings_fields('vegavend_general_options_group'); ?>
                    <table class="form-table">
                        <tr valign="top">
                            <th scope="row">
                                <?php esc_html_e('Synchronization Setting', 'vegavend-merchant-connector'); ?>
                                <span class="dashicons dashicons-editor-help" title="<?php esc_attr_e('Choose whether to sync all products or only the products you set.', 'vegavend-merchant-connector'); ?>"></span>
                            </th>
                            <td>
                                <select name="vegavend_sync_setting" id="vegavend_sync_setting">
                                    <option value="sync_all" <?php selected($sync_setting, 'sync_all'); ?>><?php esc_html_e('Sync all products', 'vegavend-merchant-connector'); ?></option>
                                    <option value="sync_selected" <?php selected($sync_setting, 'sync_selected'); ?>><?php esc_html_e('Only Sync Products I Set', 'vegavend-merchant-connector'); ?></option>
                                </select>
                            </td>
                        </tr>
                        <tr valign="top">
                            <th scope="row">
                                <?php esc_html_e('Sync products via Cron', 'vegavend-merchant-connector'); ?>
                                <span class="dashicons dashicons-editor-help" title="<?php esc_attr_e('You can disable auto sync via Cron and products will only sync with VegaVend when manually updated.', 'vegavend-merchant-connector'); ?>"></span>
                            </th>
                            <td>
                                <input type="checkbox" name="vegavend_sync_via_cron" id="vegavend_sync_via_cron" value="1" <?php checked($sync_via_cron, true); ?>>
                                <p class="description"><?php esc_html_e('Enable this option to sync products via Cron.', 'vegavend-merchant-connector'); ?></p>
                            </td>
                        </tr>
                    </table>
                    <?php if ($all_tasks_completed && $sync_via_cron): ?>
                    <button type="button" id="vegavend-sync-all" class="button button-primary" style="background-color: orange; border-color: orange; float: left;">
                        <?php esc_html_e('Sync All', 'vegavend-merchant-connector'); ?>
                    </button>
                    <?php endif; ?>
                    <div style="text-align: right;">
                        <?php submit_button(__('Save Settings', 'vegavend-merchant-connector'), 'primary', 'vegavend-save-settings', false, array('class' => 'vegavend-save-settings')); ?>
                    </div>
                </form>
            </div>
            <?php endif; ?>
            <?php if ($is_connected && !$all_tasks_completed): ?>
            <div class="card">
                <h2>
                    <?php esc_html_e('Tasks to be Completed', 'vegavend-merchant-connector'); ?>
                    <span class="dashicons dashicons-editor-help" title="<?php esc_attr_e('Auto synchronization of products with VegaVend will only be enabled when all the tasks have been completed.', 'vegavend-merchant-connector'); ?>"></span>
                </h2>
                <ul>
                    <?php foreach ($tasks as $task => $completed): ?>
                    <li>
                        <span style="color: <?php echo $completed ? 'green' : 'red'; ?>; font-size: 20px;">●</span>
                        <?php echo esc_html($task); ?>
                    </li>
                    <?php endforeach; ?>
                </ul>
                <div style="text-align: right; margin-top: 20px;">
                    <a href="<?php echo esc_url(admin_url('admin.php?page=vegavend-account')); ?>" class="button button-primary">
                        <?php echo $this->are_all_tasks_completed($tasks) ? esc_html__('Complete Setup', 'vegavend-merchant-connector') : esc_html__('Get Started', 'vegavend-merchant-connector'); ?>
                    </a>
                </div>
            </div>
            <?php endif; ?>
        </div>
        <?php
    }

    public function vegavend_enqueue_scripts($hook) {
        wp_enqueue_script('jquery');
        wp_enqueue_script('vegavend-settings', plugins_url('/assets/js/vegavend-settings.js', dirname(__FILE__)), array('jquery'), time(), true);
        wp_localize_script('vegavend-settings', 'vegavendSettings', array(
            'nonce' => wp_create_nonce('vegavend_nonce_action'),
            'ajaxurl' => admin_url('admin-ajax.php'),
            'confirmDisconnect' => __('Are you sure you would like to disconnect your site from VegaVend?', 'vegavend-merchant-connector'),
            'storeIdDeleted' => __('Store ID deleted successfully.', 'vegavend-merchant-connector'),
            'storeIdDeleteFailed' => __('Failed to delete Store ID.', 'vegavend-merchant-connector'),
            'ajaxFailed' => __('AJAX request failed:', 'vegavend-merchant-connector'),
            'confirmSyncAll' => __('Are you sure you want to schedule all your products to synchronize with VegaVend?', 'vegavend-merchant-connector'),
            'syncAllSuccess' => __('All products have been successfully scheduled for synchronization with VegaVend.', 'vegavend-merchant-connector'),
            'syncAllFailed' => __('Failed to schedule all products.', 'vegavend-merchant-connector'),
            'allTasksCompleted' => $this->are_all_tasks_completed($this->get_tasks_status(get_option('vegavend_store_id'))),
            'successMessage' => __('Congratulations, your store has been set up successfully!', 'vegavend-merchant-connector'),
        ));
    }

    public function vegavend_check_store_id() {
        check_ajax_referer('vegavend_nonce_action', 'vegavend_nonce');
        if (isset($_POST['store_id'])) {
            $store_id = sanitize_text_field(wp_unslash($_POST['store_id']));
            $api_url = Vegavend_API_Config::get_subscription_report_url();
            $args = array(
                'method' => 'POST',
                'body' => wp_json_encode(array('store_id' => $store_id)),
                'headers' => array(
                    'Content-Type' => 'application/json',
                    'X-API-Key' => Vegavend_API_Config::get_api_key(),
                ),
                'timeout' => 60,
                'redirection' => 10,
            );

            $response = wp_remote_post($api_url, $args);

            if (is_wp_error($response)) {
                wp_send_json_error(__('Error checking store ID.', 'vegavend-merchant-connector'));
            }

            $response_body = wp_remote_retrieve_body($response);
            $result = json_decode($response_body, true);

            if (isset($result['status']) && $result['status'] === 'success') {
                wp_send_json_success();
            } else {
                wp_send_json_error(__('Invalid store ID.', 'vegavend-merchant-connector'));
            }
        } else {
            wp_send_json_error(__('Store ID not provided.', 'vegavend-merchant-connector'));
        }
    }

    public function vegavend_delete_store_id() {
        check_ajax_referer('vegavend_nonce_action', 'vegavend_nonce');
        $result = delete_option('vegavend_store_id');
        if ($result) {
            wp_send_json_success();
        } else {
            wp_send_json_error(__('Failed to delete Store ID.', 'vegavend-merchant-connector'));
        }
    }

    public function vegavend_get_store_id() {
        check_ajax_referer('vegavend_nonce_action', 'vegavend_nonce');
        $store_id = get_option('vegavend_store_id');
        if ($store_id) {
            wp_send_json_success(array('store_id' => $store_id));
        } else {
            wp_send_json_error();
        }
    }

    private function vegavend_check_store_id_sync($store_id) {
        $api_url = Vegavend_API_Config::get_subscription_report_url();
        $args = array(
            'method' => 'POST',
            'body' => wp_json_encode(array('store_id' => $store_id)),
            'headers' => array(
                'Content-Type' => 'application/json',
                'X-API-Key' => Vegavend_API_Config::get_api_key(),
            ),
            'timeout' => 60,
            'redirection' => 10,
        );

        $response = wp_remote_post($api_url, $args);

        if (is_wp_error($response)) {
            return false;
        }

        $response_body = wp_remote_retrieve_body($response);
        $result = json_decode($response_body, true);

        return isset($result['status']) && $result['status'] === 'success';
    }

    private function vegavend_mask_store_id($store_id) {
        if (strlen($store_id) > 4) {
            return str_repeat('*', strlen($store_id) - 4) . substr($store_id, -4);
        }
        return $store_id;
    }

    private function get_tasks_status($store_id) {
        $vegavend_store_address_country = get_option('vegavend_store_address_country');
        $woocommerce_store_address_country = get_option('woocommerce_default_country');
        $total_sales = $this->get_woocommerce_total_sales();
        $tax_status = get_option('woocommerce_calc_taxes') === 'yes';

        $tasks = array(
            'Add Profile Picture' => !empty(get_option('vegavend_profile_picture')),
            'Add Store Banner' => !empty(get_option('vegavend_store_banner')),
            'Add Company Name' => !empty(get_option('vegavend_company_name')),
            'Add Phone Number' => !empty(get_option('vegavend_phone_number')),
            'Add Store Address' => !empty(get_option('vegavend_store_address_street')) && !empty(get_option('vegavend_store_address_city')) && !empty(get_option('vegavend_store_address_postcode')) && !empty(get_option('vegavend_store_address_country')),
            'Add Company ID' => !empty(get_option('vegavend_company_id')),
            'Add Biography' => !empty(get_option('vegavend_biography')),
            'Terms and Conditions' => !empty(get_option('vegavend_terms_and_conditions')),
            'Refunds Policy' => !empty(get_option('vegavend_refunds_policy')),
            'Shipping Policy' => !empty(get_option('vegavend_shipping_policy')),
            'Warranty Policy' => !empty(get_option('vegavend_warranty_policy')),
            'Basic Shipping ' => $this->is_basic_shipping_completed(),
            'Social Profiles' => !empty(get_option('vegavend_social_profiles')),
            'Store SEO' => !empty(get_option('vegavend_store_seo_title')) && !empty(get_option('vegavend_store_seo_meta_description')) && !empty(get_option('vegavend_store_seo_keywords')),
            'Payment Methods' => !empty(get_option('vegavend_stripe_connected')),
            'Account Verification' => $this->is_verification_approved('vegavend_identification_verified') && $this->is_verification_approved('vegavend_address_verified') && $this->is_verification_approved('vegavend_company_id_verified'),
        );

        if ($total_sales > 75000 || $vegavend_store_address_country !== 'GB' || $woocommerce_store_address_country !== 'GB' || $tax_status) {
            $tasks['Add VAT Number'] = !empty(get_option('vegavend_vat_number'));
            $tasks['Account Verification'] = $this->is_verification_approved('vegavend_identification_verified') && $this->is_verification_approved('vegavend_address_verified') && $this->is_verification_approved('vegavend_company_id_verified') && $this->is_verification_approved('vegavend_vat_number_verified');
        }

        return $tasks;
    }

    private function is_basic_shipping_completed() {
        $shipping_methods = maybe_unserialize(get_option('vegavend_shipping_methods'));
        if (is_array($shipping_methods)) {
            foreach ($shipping_methods as $method) {
                if (!empty($method['cost']) || !empty($method['free_shipping_min_amount'])) {
                    return true;
                }
            }
        }
        return false;
    }

    private function is_verification_approved($option_name) {
        $status = get_option($option_name);
        return $status === 'Approved' || $status === 'green';
    }

    private function get_woocommerce_total_sales() {
        global $wpdb;
        $total_sales = $wpdb->get_var("
            SELECT SUM(meta_value)
            FROM {$wpdb->prefix}postmeta
            WHERE meta_key = '_order_total'
        ");
        return floatval($total_sales);
    }

    private function are_all_tasks_completed($tasks) {
        foreach ($tasks as $task => $completed) {
            if ($task !== 'Account Verification' && !$completed) {
                return false;
            }
        }
        return true;
    }
}

new Vegavend_Settings_Page();
?>