<?php
if ( ! defined( 'ABSPATH' ) ) exit;

require_once plugin_dir_path(__FILE__) . 'vegavend_api_config.php';

class Vegavend_Status_Page {

    public function __construct() {
        add_action('wp_ajax_get_product_status_data', array($this, 'vegavend_get_product_status_data_ajax'));
        add_action('wp_ajax_get_total_products', array($this, 'vegavend_get_total_products_ajax'));
        add_action('admin_enqueue_scripts', array($this, 'vegavend_enqueue_scripts'));
    }

    public function vegavend_enqueue_scripts() {
        wp_enqueue_script('jquery');
        wp_enqueue_script('vegavend-status', plugins_url('/assets/js/vegavend-status.js', dirname(__FILE__)), array('jquery'), time(), true);
        wp_enqueue_style('vegavend-status', plugins_url('/assets/css/vegavend-status.css', dirname(__FILE__)), array(), time());
        wp_localize_script('vegavend-status', 'vegavendStatus', array(
            'ajaxurl' => admin_url('admin-ajax.php'),
            'nonceProductStatus' => wp_create_nonce('get_product_status_data'),
            'nonceTotalProducts' => wp_create_nonce('get_total_products'),
            'failedLoadProductStatus' => __('Failed to load product status.', 'vegavend-merchant-connector'),
            'failedLoadTotalProducts' => __('Failed to load total products.', 'vegavend-merchant-connector')
        ));
    }

    public function vegavend_status_page() {
        $store_id = get_option('vegavend_store_id');
        if (!$store_id) {
            ?>
            <div class="wrap">
                <h1><?php esc_html_e('VegaVend Account Status', 'vegavend-merchant-connector'); ?></h1>
                <p><?php echo esc_html__('Please connect your store to VegaVend to view the account status.', 'vegavend-merchant-connector'); ?></p>
            </div>
            <?php
            return;
        }
        $subscription_data = $this->vegavend_get_subscription_data($store_id);
        $total_products = $this->vegavend_get_total_products_available_for_sync();
        $allowed_products = esc_html($subscription_data->data->no_of_product);

        if ($allowed_products !== 'unlimited' && $total_products > $allowed_products) {
            add_action('admin_footer', array($this, 'vegavend_show_upgrade_popup'));
        }
        ?>
        <div class="wrap">
            <h1><?php esc_html_e('VegaVend Account Status', 'vegavend-merchant-connector'); ?></h1>
            <div class="vegavend-status-container">
                <div class="card">
                    <h2><?php esc_html_e('Subscription Plan', 'vegavend-merchant-connector'); ?></h2>
                    <?php $this->vegavend_render_subscription_info($subscription_data); ?>
                </div>
                <div class="card">
                    <h2><?php esc_html_e('Product Status', 'vegavend-merchant-connector'); ?></h2>
                    <div id="product-status-loading">
                        <p><?php esc_html_e('Loading product status', 'vegavend-merchant-connector'); ?><span id="loading-dots"></span></p>
                    </div>
                    <div id="product-status-content" style="display: none;">
                        <?php $this->vegavend_render_product_status_placeholder(); ?>
                    </div>
                </div>
                <div id="product-issues-card" class="card">
                    <h2><?php esc_html_e('Product Issues', 'vegavend-merchant-connector'); ?></h2>
                    <div class="vegavend-product-issues-container">
                        <div id="product-issues-content"></div>
                        <a href="<?php echo esc_url(admin_url('admin.php?page=vegavend-product-issues')); ?>" class="button button-primary">
                            <?php esc_html_e('Fix Product Issues', 'vegavend-merchant-connector'); ?>
                        </a>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }

    public function vegavend_show_upgrade_popup() {
        $base_url = Vegavend_API_Config::get_base_url();
        ?>
        <div id="vegavend-upgrade-popup" class="notice notice-warning is-dismissible">
            <p><?php /* Translators: %s is number of products that can be synchronized */ printf(esc_html__('Your subscription only allows for %s products to be synchronized with VegaVend. Please upgrade your plan.', 'vegavend-merchant-connector'), esc_html($allowed_products)); ?></p>
            <p><a href="<?php echo esc_url($base_url . '/dashboard/subscription/'); ?>" target="_blank" class="button button-primary"><?php esc_html_e('Upgrade Plan', 'vegavend-merchant-connector'); ?></a></p>
        </div>
        <script type="text/javascript">
            jQuery(document).ready(function($) {
                $('#vegavend-upgrade-popup').on('click', '.notice-dismiss', function() {
                    $(this).closest('.notice').remove();
                });
            });
        </script>
        <?php
    }

    private function vegavend_get_subscription_data($store_id) {
        $url = Vegavend_API_Config::get_subscription_report_url();
        $body = wp_json_encode(array('store_id' => $store_id));
        $args = array(
            'method' => 'POST',
            'body' => $body,
            'headers' => array(
                'X-API-Key' => Vegavend_API_Config::get_api_key(),
                'Content-Type' => 'application/json',
            ),
            'timeout' => 60,
            'redirection' => 10,
        );
        $response = wp_remote_post($url, $args);
        if (is_wp_error($response)) {
            return false;
        }
        return json_decode(wp_remote_retrieve_body($response));
    }

    public function vegavend_get_product_status_data_ajax() {
        check_ajax_referer('get_product_status_data', '_ajax_nonce');
        $store_id = get_option('vegavend_store_id');
        $product_status_data = $this->vegavend_get_product_status_data($store_id);
        $html = $this->vegavend_render_product_status($product_status_data, true);
        $issues_html = $this->vegavend_render_product_issues($product_status_data, true);
        $has_issues = isset($product_status_data->data->Issues) && $product_status_data->data->Issues > 0;
        wp_send_json_success(array('html' => $html, 'issues_html' => $issues_html, 'has_issues' => $has_issues));
    }

    public function vegavend_get_total_products_ajax() {
        check_ajax_referer('get_total_products', '_ajax_nonce');
        $total_products = $this->vegavend_get_total_products_available_for_sync();
        if ($total_products === 0) {
            wp_send_json_success(array('total_products' => __('You have not enabled sync on any products', 'vegavend-merchant-connector')));
        } else {
            wp_send_json_success(array('total_products' => $total_products));
        }
    }

    private function vegavend_get_product_status_data($store_id) {
        $url = Vegavend_API_Config::get_product_status_url();
        $body = wp_json_encode(array('store_id' => $store_id));
        $args = array(
            'method' => 'POST',
            'body' => $body,
            'headers' => array(
                'X-API-Key' => Vegavend_API_Config::get_api_key(),
                'Content-Type' => 'application/json',
            ),
            'timeout' => 60,
            'redirection' => 10,
        );
        $response = wp_remote_post($url, $args);
        if (is_wp_error($response)) {
            return false;
        }
        return json_decode(wp_remote_retrieve_body($response));
    }

    private function vegavend_render_subscription_info($subscription_data) {
        if (isset($subscription_data->status) && $subscription_data->status === 'success') {
            $data_s = $subscription_data->data;
            $base_url = Vegavend_API_Config::get_base_url();
            ?>
            <div class="vegavend-subscription-info-container">
                <ul class="vegavend-subscription-info">
                    <li>
                        <?php /* Translators: %s is the name of the package */ printf(esc_html__('You are using %s package.', 'vegavend-merchant-connector'), '<strong>' . esc_html($data_s->subscription_title) . '</strong>'); ?>
                    </li>
                    <li>
                        <?php /* Translators: %1$s is the number of products, %2$s is the number of days */ printf(esc_html__('You can add %1$s product(s) for %2$s days.', 'vegavend-merchant-connector'), '<strong>' . esc_html($data_s->no_of_product) . '</strong>', '<strong>' . esc_html($data_s->valid_days) . '</strong>'); ?>
                    </li>
                    <li>
                        <?php
                        if ($data_s->end_dat === 'unlimited') {
                            esc_html_e('Your package does not have an expiration date.', 'vegavend-merchant-connector');
                        } else {
                            $date_object = new DateTime($data_s->end_dat);
                            /* Translators: %s is the expiration date of the subscription */ 
                            printf(esc_html__('Your package will expire on %s.', 'vegavend-merchant-connector'), '<strong>' . esc_html($date_object->format('F j, Y')) . '</strong>');
                        }
                        ?>
                    </li>
                    <?php if ($data_s->has_active_cancelled) : ?>
                        <li>
                            <?php /* Translators: %s is the expiration date of the subscription */ printf(esc_html__('Your subscription has been cancelled! However, it is still active until %s.', 'vegavend-merchant-connector'), '<strong>' . esc_html($date_object->format('F j, Y')) . '</strong>'); ?>
                        </li>
                    <?php endif; ?>
                </ul>
                <a href="<?php echo esc_url($base_url . '/dashboard/subscription/'); ?>" target="_blank" class="button button-primary"><?php esc_html_e('Manage Subscriptions', 'vegavend-merchant-connector'); ?></a>
            </div>
            <?php
        } else {
            echo '<p>' . esc_html__('Subscription data was not found.', 'vegavend-merchant-connector') . '</p>';
        }
    }

    private function vegavend_get_total_products_available_for_sync() {
        $sync_setting = get_option('vegavend_sync_setting', 'sync_all');
        $meta_query = array();

        if ($sync_setting === 'sync_selected') {
            $meta_query = array(
                array(
                    'key' => '_vegavend_enable_sync',
                    'value' => 'on',
                ),
            );
        } else {
            $meta_query = array(
                'relation' => 'OR',
                array(
                    'key' => '_vegavend_enable_sync',
                    'value' => 'on',
                ),
                array(
                    'key' => '_vegavend_enable_sync',
                    'compare' => 'NOT EXISTS',
                ),
            );
        }

        $args = array(
            'post_type' => 'product',
            'posts_per_page' => -1,
            'meta_query' => $meta_query,
        );

        $query = new WP_Query($args);
        return $query->found_posts;
    }

    private function vegavend_render_product_status_placeholder() {
        ?>
        <div class="vegavend-product-status">
            <div class="vegavend-status-item"><?php esc_html_e('Published: ....', 'vegavend-merchant-connector'); ?><span class="status-dots"></span></div>
            <div class="vegavend-status-item"><?php esc_html_e('Pending Review: ....', 'vegavend-merchant-connector'); ?><span class="status-dots"></span></div>
        </div>
        <?php
    }

    private function vegavend_render_product_status($product_status_data, $return_html = false) {
        ob_start();
        ?>
        <p class="vegavend-total-products">
            <?php /* Translators: %s is the total number of products */ esc_html_e('Total products available: ', 'vegavend-merchant-connector'); ?>
            <strong id="total-products"></strong><span id="total-products-dots"></span>
        </p>
        <p><?php esc_html_e('Here are the current statuses of products in your VegaVend Store:', 'vegavend-merchant-connector'); ?></p>
        <?php
        if (isset($product_status_data->status) && $product_status_data->status === 'success') {
            ?>
            <div class="vegavend-product-status">
                <div class="vegavend-status-item">
                    <span style="color: green;">●</span>
                    <?php /* Translators: %s is the number of published products */ printf(esc_html__('Published: %s', 'vegavend-merchant-connector'), '<strong><span class="vegavend-status-count">' . esc_html($product_status_data->data->Published) . '</span></strong><span class="status-dots"></span>'); ?>
                </div>
                <div class="vegavend-status-item">
                    <span style="color: orange;">●</span>
                    <?php /* Translators: %s is the number of products pending review */ printf(esc_html__('Pending Review: %s', 'vegavend-merchant-connector'), '<strong><span class="vegavend-status-count">' . esc_html($product_status_data->data->pending_review) . '</span></strong><span class="status-dots"></span>'); ?>
                </div>
            </div>
            <?php
        } else {
            echo '<p>' . esc_html__('Product data was not found.', 'vegavend-merchant-connector') . '</p>';
        }
        if ($return_html) {
            return ob_get_clean();
        }
    }

    private function vegavend_render_product_issues($product_status_data, $return_html = false) {
        ob_start();
        if (isset($product_status_data->status) && $product_status_data->status === 'success') {
            ?>
            <div class="vegavend-product-issues">
                <div class="vegavend-issues-item">
                    <span style="color: red;">●</span>
                    <?php /* Translators: %s is the number of product issues */ printf(esc_html__('Product Issues: %s', 'vegavend-merchant-connector'), '<strong><span class="vegavend-issues-count">' . esc_html($product_status_data->data->Issues) . '</span></strong><span class="status-dots"></span>'); ?>
                </div>
            </div>
            <?php
        } else {
            echo '<p>' . esc_html__('Product issues data was not found.', 'vegavend-merchant-connector') . '</p>';
        }
        if ($return_html) {
            return ob_get_clean();
        }
    }
}

new Vegavend_Status_Page();